--######################################################################################################
-- FILE          : XCVR_Top
-- RELATED FILES :
-- DESCRIPTION   : This is the top level transceiver file
--               : PHY wrappers are instantiated by entering >0 in the Num* Generics
--               : Tx PLL type for each wrapper is chosen by the generic
--               : High speed serial clock type for each wrapper is chosen by the generic
--               : Static datarate for each wrapper is chosen by the *Rate generic
--               : The REFCLK is chosen by the *refclk_sel generic
--               : A signal integrity mux is instantiated with the Boolean *EnSIPatterns generic switch
--               :
-- AUTHOR        : James Murray 
-- DEPARTMENT    : European Regional Application Engineering
-- COMPANY       : Intel PSG
--######################################################################################################

library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_unsigned.all;

entity XCVR_Top is
	generic(

--############################################################################
-- Duplex PHYs
--############################################################################

			NumLHDx0:integer:=0;			-- Total number of Channels in this group
			LHDx0_TxPLL:string:="ATX"; 	-- Enter "ATX, "CMU" or "FPLL" depending on your requirement. Not all rtes supported by all PLLs
			LHDx0_SCLK:string:="x1";		-- Enter "x1" or x24. > 6 channels spanning banks must use "x24". CMU does not have access to x24 so must use x1 and cannot drive more than 5 channels.
			LHDx0_Rate:string:="10G3";		-- Enter "9G8, "10G1", "10G3", "11G3", "12G5", "17G4", "USR0", "USR1", "USR2", "USR3". -- USRn lets you configure the PHY and PLL for your rates. Not all rates supported by all PLLs
			LHDx0_EnSIPatterns:boolean:= TRUE;	-- Enter TRUE of FALSE. This enables Step, Impulse, and CLK patterns that you can control with In System Source and Probes.	
			LHDx0_refclk_sel:string:="R4LB";	-- Enter REFCLK choice here. Example1 REFCLK_GXBL1K_CHB = L1KB, Example2 REFCLK_GXBR4C_CHB = R4CB	
	
			NumLHDx1:integer:=0;			-- Total number of Channels in this group
			LHDx1_TxPLL:string:="ATX"; 	-- Enter "ATX, "CMU" or "FPLL" depending on your requirement. Not all rtes supported by all PLLs
			LHDx1_SCLK:string:="x24";		-- Enter "x1" or x24. > 6 channels spanning banks must use "x24". CMU does not have access to x24 so must use x1 and cannot drive more than 5 channels.
			LHDx1_Rate:string:="12G5";		-- Enter "9G8, "10G1", "10G3", "11G3", "12G5", "17G4", "USR0", "USR1", "USR2", "USR3". -- USRn lets you configure the PHY and PLL for your rates. Not all rates supported by all PLLs
			LHDx1_EnSIPatterns:boolean:= TRUE;	-- Enter TRUE of FALSE. This enables Step, Impulse, and CLK patterns that you can control with In System Source and Probes.			
			LHDx1_refclk_sel:string:="L1LT";	-- Enter REFCLK choice here. Example1 REFCLK_GXBL1K_CHB = L1KB, Example2 REFCLK_GXBR4C_CHB = R4CB				
			
			NumLHDx2:integer:=0;			-- Total number of Channels in this group				
			LHDx2_TxPLL:string:="ATX"; 	-- Enter "ATX, "CMU" or "FPLL" depending on your requirement. Not all rtes supported by all PLLs
			LHDx2_SCLK:string:="x1";		-- Enter "x1" or x24. > 6 channels spanning banks must use "x24". CMU does not have access to x24 so must use x1 and cannot drive more than 5 channels.
			LHDx2_Rate:string:="10G3";		-- Enter "9G8, "10G1", "10G3", "11G3", "12G5", "17G4", "USR0", "USR1", "USR2", "USR3". -- USRn lets you configure the PHY and PLL for your rates. Not all rates supported by all PLLs
			LHDx2_EnSIPatterns:boolean:= TRUE;	-- Enter TRUE of FALSE. This enables Step, Impulse, and CLK patterns that you can control with In System Source and Probes.			
			LHDx2_refclk_sel:string:="R4CB";	-- Enter REFCLK choice here. Example1 REFCLK_GXBL1K_CHB = L1KB, Example2 REFCLK_GXBR4C_CHB = R4CB				
						
			NumLHDx3:integer:=0;			-- Total number of Channels in this group				
			LHDx3_TxPLL:string:="ATX"; 	-- Enter "ATX, "CMU" or "FPLL" depending on your requirement. Not all rtes supported by all PLLs
			LHDx3_SCLK:string:="x1";		-- Enter "x1" or x24. > 6 channels spanning banks must use "x24". CMU does not have access to x24 so must use x1 and cannot drive more than 5 channels.
			LHDx3_Rate:string:="11G3";		-- Enter "9G8, "10G1", "10G3", "11G3", "12G5", "17G4", "USR0", "USR1", "USR2", "USR3". -- USRn lets you configure the PHY and PLL for your rates. Not all rates supported by all PLLs
			LHDx3_EnSIPatterns:boolean:= TRUE;	-- Enter TRUE of FALSE. This enables Step, Impulse, and CLK patterns that you can control with In System Source and Probes.			
			LHDx3_refclk_sel:string:="L1DT";						
						
			NumLHDx4:integer:=0;			-- Total number of Channels in this group
			LHDx4_TxPLL:string:="ATX"; 	-- Enter "ATX, "CMU" or "FPLL" depending on your requirement. Not all rtes supported by all PLLs
			LHDx4_SCLK:string:="x1";		-- Enter "x1" or x24. > 6 channels spanning banks must use "x24". CMU does not have access to x24 so must use x1 and cannot drive more than 5 channels.
			LHDx4_Rate:string:="USR2";		-- Enter "9G8, "10G1", "10G3", "11G3", "12G5", "17G4", "USR0", "USR1", "USR2", "USR3". -- USRn lets you configure the PHY and PLL for your rates. Not all rates supported by all PLLs
			LHDx4_EnSIPatterns:boolean:= TRUE;	-- Enter TRUE of FALSE. This enables Step, Impulse, and CLK patterns that you can control with In System Source and Probes.			
			LHDx4_refclk_sel:string:="L1EB";	-- Enter REFCLK choice here. Example1 REFCLK_GXBL1K_CHB = L1KB, Example2 REFCLK_GXBR4C_CHB = R4CB	
				
			NumLHDx5:integer:=0;			-- Total number of Channels in this group
			LHDx5_TxPLL:string:="ATX"; 	-- Enter "ATX, "CMU" or "FPLL" depending on your requirement. Not all rtes supported by all PLLs
			LHDx5_SCLK:string:="x1";		-- Enter "x1" or x24. > 6 channels spanning banks must use "x24". CMU does not have access to x24 so must use x1 and cannot drive more than 5 channels.
			LHDx5_Rate:string:="USR0";		-- Enter "9G8, "10G1", "10G3", "11G3", "12G5", "17G4", "USR0", "USR1", "USR2", "USR3". -- USRn lets you configure the PHY and PLL for your rates. Not all rates supported by all PLLs
			LHDx5_EnSIPatterns:boolean:= TRUE;	-- Enter TRUE of FALSE. This enables Step, Impulse, and CLK patterns that you can control with In System Source and Probes.			
			LHDx5_refclk_sel:string:="L1ET";	-- Enter REFCLK choice here. Example1 REFCLK_GXBL1K_CHB = L1KB, Example2 REFCLK_GXBR4C_CHB = R4CB							
						
			NumLHDx6:integer:=0;			-- Total number of Channels in this group				
			LHDx6_TxPLL:string:="ATX"; 	-- Enter "ATX, "CMU" or "FPLL" depending on your requirement. Not all rtes supported by all PLLs
			LHDx6_SCLK:string:="x1";		-- Enter "x1" or x24. > 6 channels spanning banks must use "x24". CMU does not have access to x24 so must use x1 and cannot drive more than 5 channels.
			LHDx6_Rate:string:="USR1";		-- Enter "9G8, "10G1", "10G3", "11G3", "12G5", "17G4", "USR0", "USR1", "USR2", "USR3". -- USRn lets you configure the PHY and PLL for your rates. Not all rates supported by all PLLs
			LHDx6_EnSIPatterns:boolean:= TRUE;	-- Enter TRUE of FALSE. This enables Step, Impulse, and CLK patterns that you can control with In System Source and Probes.			
			LHDx6_refclk_sel:string:="L1FB";	-- Enter REFCLK choice here. Example1 REFCLK_GXBL1K_CHB = L1KB, Example2 REFCLK_GXBR4C_CHB = R4CB										
			
			NumLHDx7:integer:=0;			-- Total number of Channels in this group				
			LHDx7_TxPLL:string:="ATX"; 	-- Enter "ATX, "CMU" or "FPLL" depending on your requirement. Not all rtes supported by all PLLs
			LHDx7_SCLK:string:="x1";		-- Enter "x1" or x24. > 6 channels spanning banks must use "x24". CMU does not have access to x24 so must use x1 and cannot drive more than 5 channels.
			LHDx7_Rate:string:="USR3";		-- Enter "9G8, "10G1", "10G3", "11G3", "12G5", "17G4", "USR0", "USR1", "USR2", "USR3". -- USRn lets you configure the PHY and PLL for your rates. Not all rates supported by all PLLs
			LHDx7_EnSIPatterns:boolean:= TRUE;	-- Enter TRUE of FALSE. This enables Step, Impulse, and CLK patterns that you can control with In System Source and Probes.			
			LHDx7_refclk_sel:string:="L1FT";	-- Enter REFCLK choice here. Example1 REFCLK_GXBL1K_CHB = L1KB, Example2 REFCLK_GXBR4C_CHB = R4CB												
						
--############################################################################
-- Simplex Tx Only PHYs
--############################################################################

			NumLHTx0:integer:=0;			-- Total number of Channels in this group			
			LHTx0_TxPLL:string:="ATX"; 	-- Enter "ATX, "CMU" or "FPLL" depending on your requirement. Not all rtes supported by all PLLs
			LHTx0_SCLK:string:="x1";		-- Enter "x1" or x24. > 6 channels spanning banks must use "x24". CMU does not have access to x24 so must use x1 and cannot drive more than 5 channels.
			LHTx0_Rate:string:="12G5";		-- Enter "9G8, "10G1", "10G3", "11G3", "12G5", "17G4", "USR0", "USR1", "USR2", "USR3". -- USRn lets you configure the PHY and PLL for your rates. Not all rates supported by all PLLs
			LHTx0_EnSIPatterns:boolean:= TRUE;	-- Enter TRUE of FALSE. This enables Step, Impulse, and CLK patterns that you can control with In System Source and Probes.			G5
			LHTx0_refclk_sel:string:="L1LB";	-- Enter REFCLK choice here. Example1 REFCLK_GXBL1K_CHB = L1KB, Example2 REFCLK_GXBR4C_CHB = R4CB										
			
			NumLHTx1:integer:=0;			-- Total number of Channels in this group
			LHTx1_TxPLL:string:="ATX"; 	-- Enter "ATX, "CMU" or "FPLL" depending on your requirement. Not all rtes supported by all PLLs
			LHTx1_SCLK:string:="x24";		-- Enter "x1" or x24. > 6 channels spanning banks must use "x24". CMU does not have access to x24 so must use x1 and cannot drive more than 5 channels.
			LHTx1_Rate:string:="17G4";		-- Enter "9G8, "10G1", "10G3", "11G3", "12G5", "17G4", "USR0", "USR1", "USR2", "USR3". -- USRn lets you configure the PHY and PLL for your rates. Not all rates supported by all PLLs
			LHTx1_EnSIPatterns:boolean:= TRUE;	-- Enter TRUE of FALSE. This enables Step, Impulse, and CLK patterns that you can control with In System Source and Probes.						
			LHTx1_refclk_sel:string:="L1KT";	-- Enter REFCLK choice here. Example1 REFCLK_GXBL1K_CHB = L1KB, Example2 REFCLK_GXBR4C_CHB = R4CB										
			
			NumLHTx2:integer:=0;			-- Total number of Channels in this group			
			LHTx2_TxPLL:string:="ATX"; 	-- Enter "ATX, "CMU" or "FPLL" depending on your requirement. Not all rtes supported by all PLLs
			LHTx2_SCLK:string:="x1";		-- Enter "x1" or x24. > 6 channels spanning banks must use "x24". CMU does not have access to x24 so must use x1 and cannot drive more than 5 channels.
			LHTx2_Rate:string:="10G3";		-- Enter "9G8, "10G1", "10G3", "11G3", "12G5", "17G4", "USR0", "USR1", "USR2", "USR3". -- USRn lets you configure the PHY and PLL for your rates. Not all rates supported by all PLLs
			LHTx2_EnSIPatterns:boolean:= TRUE;	-- Enter TRUE of FALSE. This enables Step, Impulse, and CLK patterns that you can control with In System Source and Probes.			
			LHTx2_refclk_sel:string:="L1LB";	-- Enter REFCLK choice here. Example1 REFCLK_GXBL1K_CHB = L1KB, Example2 REFCLK_GXBR4C_CHB = R4CB										
			
			NumLHTx3:integer:=0;			-- Total number of Channels in this group
			LHTx3_TxPLL:string:="ATX"; 	-- Enter "ATX, "CMU" or "FPLL" depending on your requirement. Not all rtes supported by all PLLs
			LHTx3_SCLK:string:="x24";		-- Enter "x1" or x24. > 6 channels spanning banks must use "x24". CMU does not have access to x24 so must use x1 and cannot drive more than 5 channels.
			LHTx3_Rate:string:="11G3";		-- Enter "9G8, "10G1", "10G3", "11G3", "12G5", "17G4", "USR0", "USR1", "USR2", "USR3". -- USRn lets you configure the PHY and PLL for your rates. Not all rates supported by all PLLs
			LHTx3_EnSIPatterns:boolean:= TRUE;	-- Enter TRUE of FALSE. This enables Step, Impulse, and CLK patterns that you can control with In System Source and Probes.			
			LHTx3_refclk_sel:string:="L1LB";	-- Enter REFCLK choice here. Example1 REFCLK_GXBL1K_CHB = L1KB, Example2 REFCLK_GXBR4C_CHB = R4CB																
			
--############################################################################
-- Simplex Rx Only PHYs
--############################################################################

			NumLHRx0:integer:=0;			-- Total number of Channels in this group
			LHRx0_Rate:string:="USR1";		-- Enter "9G8, "10G1", "10G3", "11G3", "12G5", "17G4", "USR0", "USR1", "USR2", "USR3". -- USRn lets you configure the PHY and PLL for your rates.
			LHRx0_refclk_sel:string:="L1LB";	-- Enter REFCLK choice here. Example1 REFCLK_GXBL1K_CHB = L1KB, Example2 REFCLK_GXBR4C_CHB = R4CB													

			NumLHRx1:integer:=0;			-- Total number of Channels in this group
			LHRx1_Rate:string:="USR2";		-- Enter "9G8, "10G1", "10G3", "11G3", "12G5", "17G4", "USR0", "USR1", "USR2", "USR3". -- USRn lets you configure the PHY and PLL for your rates.
			LHRx1_refclk_sel:string:="L1MTB";	-- Enter REFCLK choice here. Example1 REFCLK_GXBL1K_CHB = L1KB, Example2 REFCLK_GXBR4C_CHB = R4CB										
			
			NumLHRx2:integer:=0;			-- Total number of Channels in this group
			LHRx2_Rate:string:="USR0";		-- Enter "9G8, "10G1", "10G3", "11G3", "12G5", "17G4", "USR0", "USR1", "USR2", "USR3". -- USRn lets you configure the PHY and PLL for your rates.
			LHRx2_refclk_sel:string:="L1NB";	-- Enter REFCLK choice here. Example1 REFCLK_GXBL1K_CHB = L1KB, Example2 REFCLK_GXBR4C_CHB = R4CB										
			
			NumLHRx3:integer:=0;			-- Total number of Channels in this group
			LHRx3_Rate:string:="USR3";		-- Enter "9G8, "10G1", "10G3", "11G3", "12G5", "17G4", "USR0", "USR1", "USR2", "USR3". -- USRn lets you configure the PHY and PLL for your rates.
			LHRx3_refclk_sel:string:="L1NT";	-- Enter REFCLK choice here. Example1 REFCLK_GXBL1K_CHB = L1KB, Example2 REFCLK_GXBR4C_CHB = R4CB										
						
--############################################################################ 
-- GXT Duplex PHYs
--############################################################################
-- Each ATX PLL can only drive two GXT channels directly. 0 & 1 for bottom ATX, and 3 & 4 for top ATX
-- Cascading above and below lets you drive a total of 6 channels per cluster
-- For this design, your 1st channel must use a socalled Main ATX PLL. You then cascade up or down from there.
-- The Generics let you define how many Above, Main, and Below channels you would like.			

			NumLHGT0abv:integer:=2;	-- Total number of GXT channels clocked from the above ATX. The above ATX is cascaded from the Main ATX.
			NumLHGT0main:integer:=2;	-- Total number of GXT channels clocked from the Main ATX PLL. This field relates to the master ATX which cascades to the above and below ATX so must be populated first.
			NumLHGT0blw:integer:=0;	-- Total number of GXT channels clocked from the below ATX. The below ATX is cascaded from the Main ATX.
			LHGT0_refclk_sel:string:="L1DB";
			LHGT0_Rate:string:= "25G8";   -- Enter "24G3, "25G8", "28G0", "28G3", "USR0, "USR1"	
			LHGT0_EnSIPatterns:boolean:= TRUE;	-- Enter TRUE of FALSE. This enables Step, Impulse, and CLK patterns that you can control with In System Source and Probes.				
						
			NumLHGT1abv:integer:=2;	-- Total number of GXT channels clocked from the above ATX. The above ATX is cascaded from the Main ATX.
			NumLHGT1main:integer:=2;	-- Total number of GXT channels clocked from the Main ATX PLL. This field relates to the master ATX which cascades to the above and below ATX so must be populated first.
			NumLHGT1blw:integer:=0;	-- Total number of GXT channels clocked from the below ATX. The below ATX is cascaded from the Main ATX.
			LHGT1_refclk_sel:string:="L1DB";		  			
			LHGT1_Rate:string:= "25G8";   -- Enter "24G3, "25G8", "28G0", "28G3", "USR0, "USR1"		
			LHGT1_EnSIPatterns:boolean:= TRUE;	-- Enter TRUE of FALSE. This enables Step, Impulse, and CLK patterns that you can control with In System Source and Probes.										

			NumLHGT2abv:integer:=0;	-- Total number of GXT channels clocked from the above ATX. The above ATX is cascaded from the Main ATX.
			NumLHGT2main:integer:=1;	-- Total number of GXT channels clocked from the Main ATX PLL. This field relates to the master ATX which cascades to the above and below ATX so must be populated first.
			NumLHGT2blw:integer:=0;	-- Total number of GXT channels clocked from the below ATX. The below ATX is cascaded from the Main ATX.
			LHGT2_refclk_sel:string:="R4DB";		  
			LHGT2_Rate:string:= "25G8";   -- Enter "24G3, "25G8", "28G0", "28G3", "USR0, "USR1"	
			LHGT2_EnSIPatterns:boolean:= TRUE;	-- Enter TRUE of FALSE. This enables Step, Impulse, and CLK patterns that you can control with In System Source and Probes.											

			NumLHGT3abv:integer:=0;	-- Total number of GXT channels clocked from the above ATX. The above ATX is cascaded from the Main ATX.
			NumLHGT3main:integer:=0;-- Total number of GXT channels clocked from the Main ATX PLL. This field relates to the master ATX which cascades to the above and below ATX so must be populated first.
			NumLHGT3blw:integer:=0;	-- Total number of GXT channels clocked from the below ATX. The below ATX is cascaded from the Main ATX.
			LHGT3_refclk_sel:string:="L1DB";		  
			LHGT3_Rate:string:= "25G8";   -- Enter "24G3, "25G8", "28G0", "28G3", "USR0, "USR1"	
			LHGT3_EnSIPatterns:boolean:= TRUE;	-- Enter TRUE of FALSE. This enables Step, Impulse, and CLK patterns that you can control with In System Source and Probes.											

			NumLHGT4abv:integer:=0;	-- Total number of GXT channels clocked from the above ATX. The above ATX is cascaded from the Main ATX.
			NumLHGT4main:integer:=0;	-- Total number of GXT channels clocked from the Main ATX PLL. This field relates to the master ATX which cascades to the above and below ATX so must be populated first.
			NumLHGT4blw:integer:=0;	-- Total number of GXT channels clocked from the below ATX. The below ATX is cascaded from the Main ATX.
			LHGT4_refclk_sel:string:="R4EB";		  
			LHGT4_Rate:string:= "24G3";   -- Enter "24G3, "25G8", "28G0", "28G3", "USR0, "USR1"	
			LHGT4_EnSIPatterns:boolean:= TRUE;	-- Enter TRUE of FALSE. This enables Step, Impulse, and CLK patterns that you can control with In System Source and Probes.										

			NumLHGT5abv:integer:=0;	-- Total number of GXT channels clocked from the above ATX. The above ATX is cascaded from the Main ATX.
			NumLHGT5main:integer:=0;	-- Total number of GXT channels clocked from the Main ATX PLL. This field relates to the master ATX which cascades to the above and below ATX so must be populated first.
			NumLHGT5blw:integer:=0;	-- Total number of GXT channels clocked from the below ATX. The below ATX is cascaded from the Main ATX.
			LHGT5_refclk_sel:string:="R4ET";		  
			LHGT5_Rate:string:= "24G3";   -- Enter "24G3, "25G8", "28G0", "28G3", "USR0, "USR1"	
			LHGT5_EnSIPatterns:boolean:= TRUE;	-- Enter TRUE of FALSE. This enables Step, Impulse, and CLK patterns that you can control with In System Source and Probes.										

			NumLHGT6abv:integer:=0;	-- Total number of GXT channels clocked from the above ATX. The above ATX is cascaded from the Main ATX.
			NumLHGT6main:integer:=0;	-- Total number of GXT channels clocked from the Main ATX PLL. This field relates to the master ATX which cascades to the above and below ATX so must be populated first.
			NumLHGT6blw:integer:=0;	-- Total number of GXT channels clocked from the below ATX. The below ATX is cascaded from the Main ATX.
			LHGT6_refclk_sel:string:="R4FB";		  
			LHGT6_Rate:string:= "USR0";   -- Enter "24G3, "25G8", "28G0", "28G3", "USR0, "USR1"				
			LHGT6_EnSIPatterns:boolean:= TRUE;	-- Enter TRUE of FALSE. This enables Step, Impulse, and CLK patterns that you can control with In System Source and Probes.							

			NumLHGT7abv:integer:=0;	-- Total number of GXT channels clocked from the above ATX. The above ATX is cascaded from the Main ATX.
			NumLHGT7main:integer:=0;	-- Total number of GXT channels clocked from the Main ATX PLL. This field relates to the master ATX which cascades to the above and below ATX so must be populated first.
			NumLHGT7blw:integer:=0; 	-- Total number of GXT channels clocked from the below ATX. The below ATX is cascaded from the Main ATX.
			LHGT7_refclk_sel:string:="R4FT";
			LHGT7_Rate:string:= "28G3";   -- Enter "24G3, "25G8", "28G0", "28G3", "USR0, "USR1"	
			LHGT7_EnSIPatterns:boolean:= FALSE;	-- Enter TRUE of FALSE. This enables Step, Impulse, and CLK patterns that you can control with In System Source and Probes.	
			
			UnusedGeneric:boolean:=FALSE
);	
	
	port(
	
--######################################################################
-- Reference clocks ####################################################
--######################################################################

		REFCLK_R4NT, REFCLK_R4NB, REFCLK_R4MT, REFCLK_R4MB, REFCLK_R4LT, REFCLK_R4LB, REFCLK_R4KT, REFCLK_R4KB: in std_logic; --  Top right tile 	
		REFCLK_R4FT, REFCLK_R4FB, REFCLK_R4ET, REFCLK_R4EB, REFCLK_R4DT, REFCLK_R4DB, REFCLK_R4CT, REFCLK_R4CB: in std_logic; --  Bottom right tile		
		REFCLK_L1NT, REFCLK_L1NB, REFCLK_L1MT, REFCLK_L1MB,	REFCLK_L1LT, REFCLK_L1LB,	REFCLK_L1KT, REFCLK_L1KB: in std_logic; --  Top left tile
		REFCLK_L1FT, REFCLK_L1FB,	REFCLK_L1ET, REFCLK_L1EB,	REFCLK_L1DT, REFCLK_L1DB,	REFCLK_L1CT, REFCLK_L1CB: in std_logic; --  Bottom left tile				
			
--######################################################################
-- Duplex ENH PCS Channels #############################################
--######################################################################

		Tx_LHDx0      	: out std_logic_vector(NumLHDx0-1 downto 0);
		Rx_LHDx0      	: in  std_logic_vector(NumLHDx0-1 downto 0)   := (others => '0');
		                    	
		Tx_LHDx1      	: out std_logic_vector(NumLHDx1-1 downto 0);
		Rx_LHDx1      	: in  std_logic_vector(NumLHDx1-1 downto 0)   := (others => '0');

		Tx_LHDx2      	: out std_logic_vector(NumLHDx2-1 downto 0);
		Rx_LHDx2      	: in  std_logic_vector(NumLHDx2-1 downto 0)   := (others => '0');
		
		Tx_LHDx3      	: out std_logic_vector(NumLHDx3-1 downto 0);
		Rx_LHDx3      	: in  std_logic_vector(NumLHDx3-1 downto 0)   := (others => '0');		

		Tx_LHDx4      	: out std_logic_vector(NumLHDx4-1 downto 0);
		Rx_LHDx4      	: in  std_logic_vector(NumLHDx4-1 downto 0)   := (others => '0');
		                    	
		Tx_LHDx5      	: out std_logic_vector(NumLHDx5-1 downto 0);
		Rx_LHDx5      	: in  std_logic_vector(NumLHDx5-1 downto 0)   := (others => '0');

		Tx_LHDx6      	: out std_logic_vector(NumLHDx6-1 downto 0);
		Rx_LHDx6      	: in  std_logic_vector(NumLHDx6-1 downto 0)   := (others => '0');
		
		Tx_LHDx7      	: out std_logic_vector(NumLHDx7-1 downto 0);
		Rx_LHDx7      	: in  std_logic_vector(NumLHDx7-1 downto 0)   := (others => '0');		

--######################################################################
-- Simplex Tx Only Channels ############################################
--######################################################################
	
		Tx_LHTx0      	: out std_logic_vector(NumLHTx0-1 downto 0);		
		Tx_LHTx1      	: out std_logic_vector(NumLHTx1-1 downto 0);				
		Tx_LHTx2      	: out std_logic_vector(NumLHTx2-1 downto 0);		
		Tx_LHTx3      	: out std_logic_vector(NumLHTx3-1 downto 0);				
		

--######################################################################
-- Simplex Tx Only Channels ############################################
--######################################################################
	
		Rx_LHRx0      	: in std_logic_vector(NumLHRx0-1 downto 0);		
		Rx_LHRx1      	: in std_logic_vector(NumLHRx1-1 downto 0);				
		Rx_LHRx2      	: in std_logic_vector(NumLHRx2-1 downto 0);		
		Rx_LHRx3      	: in std_logic_vector(NumLHRx3-1 downto 0);				
		
--######################################################################
-- GT Channels	########################################################
--######################################################################

		Tx_LHGT0abv	: out std_logic_vector(NumLHGT0abv-1 downto 0);
		Rx_LHGT0abv	: in  std_logic_vector(NumLHGT0abv-1 downto 0);
		Tx_LHGT0main	: out std_logic_vector(NumLHGT0main-1 downto 0);
		Rx_LHGT0main	: in  std_logic_vector(NumLHGT0main-1 downto 0);
		Tx_LHGT0blw	: out std_logic_vector(NumLHGT0blw-1 downto 0);
		Rx_LHGT0blw	: in  std_logic_vector(NumLHGT0blw-1 downto 0);
		
		Tx_LHGT1abv	: out std_logic_vector(NumLHGT1abv-1 downto 0);
		Rx_LHGT1abv	: in  std_logic_vector(NumLHGT1abv-1 downto 0);
		Tx_LHGT1main	: out std_logic_vector(NumLHGT1main-1 downto 0);
		Rx_LHGT1main	: in  std_logic_vector(NumLHGT1main-1 downto 0);
		Tx_LHGT1blw	: out std_logic_vector(NumLHGT1blw-1 downto 0);
		Rx_LHGT1blw	: in  std_logic_vector(NumLHGT1blw-1 downto 0);
		
		Tx_LHGT2abv	: out std_logic_vector(NumLHGT2abv-1 downto 0);
		Rx_LHGT2abv	: in  std_logic_vector(NumLHGT2abv-1 downto 0);
		Tx_LHGT2main	: out std_logic_vector(NumLHGT2main-1 downto 0);
		Rx_LHGT2main	: in  std_logic_vector(NumLHGT2main-1 downto 0);
		Tx_LHGT2blw	: out std_logic_vector(NumLHGT2blw-1 downto 0);
		Rx_LHGT2blw	: in  std_logic_vector(NumLHGT2blw-1 downto 0);
		
		Tx_LHGT3abv	: out std_logic_vector(NumLHGT3abv-1 downto 0);
		Rx_LHGT3abv	: in  std_logic_vector(NumLHGT3abv-1 downto 0);
		Tx_LHGT3main	: out std_logic_vector(NumLHGT3main-1 downto 0);
		Rx_LHGT3main	: in  std_logic_vector(NumLHGT3main-1 downto 0);
		Tx_LHGT3blw	: out std_logic_vector(NumLHGT3blw-1 downto 0);
		Rx_LHGT3blw	: in  std_logic_vector(NumLHGT3blw-1 downto 0);
		
		Tx_LHGT4abv	: out std_logic_vector(NumLHGT4abv-1 downto 0);
		Rx_LHGT4abv	: in  std_logic_vector(NumLHGT4abv-1 downto 0);
		Tx_LHGT4main	: out std_logic_vector(NumLHGT4main-1 downto 0);
		Rx_LHGT4main	: in  std_logic_vector(NumLHGT4main-1 downto 0);
		Tx_LHGT4blw	: out std_logic_vector(NumLHGT4blw-1 downto 0);
		Rx_LHGT4blw	: in  std_logic_vector(NumLHGT4blw-1 downto 0);
		
		Tx_LHGT5abv	: out std_logic_vector(NumLHGT5abv-1 downto 0);
		Rx_LHGT5abv	: in  std_logic_vector(NumLHGT5abv-1 downto 0);
		Tx_LHGT5main	: out std_logic_vector(NumLHGT5main-1 downto 0);
		Rx_LHGT5main	: in  std_logic_vector(NumLHGT5main-1 downto 0);
		Tx_LHGT5blw	: out std_logic_vector(NumLHGT5blw-1 downto 0);
		Rx_LHGT5blw	: in  std_logic_vector(NumLHGT5blw-1 downto 0);
		
		Tx_LHGT6abv	: out std_logic_vector(NumLHGT6abv-1 downto 0);
		Rx_LHGT6abv	: in  std_logic_vector(NumLHGT6abv-1 downto 0);
		Tx_LHGT6main	: out std_logic_vector(NumLHGT6main-1 downto 0);
		Rx_LHGT6main	: in  std_logic_vector(NumLHGT6main-1 downto 0);
		Tx_LHGT6blw	: out std_logic_vector(NumLHGT6blw-1 downto 0);
		Rx_LHGT6blw	: in  std_logic_vector(NumLHGT6blw-1 downto 0);												

		Tx_LHGT7abv	: out std_logic_vector(NumLHGT7abv-1 downto 0);
		Rx_LHGT7abv	: in  std_logic_vector(NumLHGT7abv-1 downto 0);
		Tx_LHGT7main	: out std_logic_vector(NumLHGT7main-1 downto 0);		
		Rx_LHGT7main	: in  std_logic_vector(NumLHGT7main-1 downto 0);
		Tx_LHGT7blw	: out std_logic_vector(NumLHGT7blw-1 downto 0);
		Rx_LHGT7blw	: in  std_logic_vector(NumLHGT7blw-1 downto 0);	

-- ####################################################################
-- ##### USER STUFF 			#############################################
-- ####################################################################

		USER_PB					: in  std_logic_vector(7 downto 0);				
		USER_DIP				: in  std_logic_vector(6 downto 0);				
		USER_LED				: out std_logic_vector(7 downto 0);
		USER_IO				  : out std_logic_vector(9 downto 0);		

-- ####################################################################
-- ##### Simplex PHY AVMM Signals		################################
-- ####################################################################
		
--		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
--		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
--		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
--		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
--		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
--		reconfig_waitrequest    : out std_logic_vector(0 downto 0);                     -- waitrequest

		clk_100         		: in  std_logic_vector(0 downto 0)   := (others => '0')
		
	);
end entity XCVR_Top;

architecture rtl of XCVR_Top is

-- Reset Signals
	signal MasterReset         : std_logic_vector(0 downto 0):= (others => '1');
	signal ResetPB         		: std_logic:= '1';
	signal ResetPBn         	: std_logic:= '0';	

	signal PowerOnReset			: std_logic := '0';--_vector(0 downto 0)   := (others => '0');
	signal PowerOnReset_n		: std_logic := '1';--_vector(0 downto 0)   := (others => '1');
	signal ResetCount				: std_logic_vector(19 downto 0) := (OTHERS => '1');
	
	signal reconfig_write          : std_logic_vector(0 downto 0)  := (others => 'X'); -- write
	signal reconfig_read           : std_logic_vector(0 downto 0)  := (others => 'X'); -- read
	signal reconfig_address        : std_logic_vector(10 downto 0) := (others => 'X'); -- address
	signal reconfig_writedata      : std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
	signal reconfig_readdata       : std_logic_vector(31 downto 0);                    -- readdata
	signal reconfig_waitrequest    : std_logic_vector(0 downto 0);                     -- waitrequest
	
-- ####################################################################
-- ##### internal reference clocks ####################################
-- ####################################################################
	
	signal LHDx0_refclk, LHDx1_refclk, LHDx2_refclk, LHDx3_refclk, LHDx4_refclk, LHDx5_refclk, LHDx6_refclk, LHDx7_refclk: std_logic;					
	signal LHTx0_refclk, LHTx1_refclk, LHTx2_refclk, LHTx3_refclk: std_logic;					
	signal LHRx0_refclk, LHRx1_refclk, LHRx2_refclk, LHRx3_refclk: std_logic;	
	signal LHGT0_refclk, LHGT1_refclk, LHGT2_refclk, LHGT3_refclk, LHGT4_refclk, LHGT5_refclk, LHGT6_refclk, LHGT7_refclk: std_logic;						
		
-- ####################################################################
-- ##### Duplex Channels parallel clocks ##############################
-- ####################################################################

	signal LHDx0_txclkout			: std_logic_vector(NumLHDx0-1 downto 0);
	signal LHDx0_rxclkout			: std_logic_vector(NumLHDx0-1 downto 0);	
	
	signal LHDx1_txclkout			: std_logic_vector(NumLHDx1-1 downto 0);
	signal LHDx1_rxclkout			: std_logic_vector(NumLHDx1-1 downto 0);	

	signal LHDx2_txclkout			: std_logic_vector(NumLHDx2-1 downto 0);
	signal LHDx2_rxclkout			: std_logic_vector(NumLHDx2-1 downto 0);	

	signal LHDx3_txclkout			: std_logic_vector(NumLHDx3-1 downto 0);
	signal LHDx3_rxclkout			: std_logic_vector(NumLHDx3-1 downto 0);	

	signal LHDx4_txclkout			: std_logic_vector(NumLHDx4-1 downto 0);
	signal LHDx4_rxclkout			: std_logic_vector(NumLHDx4-1 downto 0);	
	
	signal LHDx5_txclkout			: std_logic_vector(NumLHDx5-1 downto 0);
	signal LHDx5_rxclkout			: std_logic_vector(NumLHDx5-1 downto 0);	

	signal LHDx6_txclkout			: std_logic_vector(NumLHDx6-1 downto 0);
	signal LHDx6_rxclkout			: std_logic_vector(NumLHDx6-1 downto 0);	

	signal LHDx7_txclkout			: std_logic_vector(NumLHDx7-1 downto 0);
	signal LHDx7_rxclkout			: std_logic_vector(NumLHDx7-1 downto 0);	
	
-- ####################################################################
-- ##### Simplex Tx Channels parallel clocks ##########################
-- ####################################################################

	signal LHTx0_txclkout			: std_logic_vector(NumLHTx0-1 downto 0);
	signal LHTx1_txclkout			: std_logic_vector(NumLHTx1-1 downto 0);
	signal LHTx2_txclkout			: std_logic_vector(NumLHTx2-1 downto 0);
	signal LHTx3_txclkout			: std_logic_vector(NumLHTx3-1 downto 0);

-- ####################################################################
-- ##### Simplex Rx Channels parallel clocks ##########################
-- ####################################################################

	signal LHRx0_rxclkout			: std_logic_vector(NumLHRx0-1 downto 0);
	signal LHRx1_rxclkout			: std_logic_vector(NumLHRx1-1 downto 0);
	signal LHRx2_rxclkout			: std_logic_vector(NumLHRx2-1 downto 0);
	signal LHRx3_rxclkout			: std_logic_vector(NumLHRx3-1 downto 0);
	
-- ####################################################################
-- ##### Duplex Channels 			#################################
-- ####################################################################

-- ##### Duplex Interface #####
component LH_Dx0_Wrap is
	generic(	NumChannels:integer:=0;
				TxPLL_Type:string:="ATX";
				SCLK_Select:string:="x24";
				Rate:string:="10G3";
				SIPatterns:boolean:=FALSE);					
	PORT(
		refclk		   	: in std_logic;
		tx_serial_data		: out std_logic_vector(NumLHDx0-1 downto 0);
		rx_serial_data		: in  std_logic_vector(NumLHDx0-1 downto 0)   := (others => '0'); 
		txclkout				: out std_logic_vector(NumLHDx0-1 downto 0);
		rxclkout				: out std_logic_vector(NumLHDx0-1 downto 0);		
		clk_100				: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in				:  in  std_logic_vector(0 downto 0)   := (others => '0')
		);
end component;

-- ##### Duplex Interface #####
component LH_Dx1_Wrap is
	generic(	NumChannels:integer:=0;
				TxPLL_Type:string:="ATX";
				SCLK_Select:string:="x24";
				Rate:string:="10G3";
				SIPatterns:boolean:=FALSE);					
	PORT(
		refclk		   	: in std_logic;
		tx_serial_data		: out std_logic_vector(NumLHDx1-1 downto 0);
		rx_serial_data		: in  std_logic_vector(NumLHDx1-1 downto 0)   := (others => '0');
		txclkout				: out std_logic_vector(NumLHDx1-1 downto 0);
		rxclkout				: out std_logic_vector(NumLHDx1-1 downto 0);		
		clk_100				: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in				:  in  std_logic_vector(0 downto 0)   := (others => '0')
		);
end component;

-- ##### Duplex Interface #####
component LH_Dx2_Wrap is
	generic(	NumChannels:integer:=0;
				TxPLL_Type:string:="ATX";
				SCLK_Select:string:="x24";
				Rate:string:="10G3";
				SIPatterns:boolean:=FALSE);					
	PORT(
		refclk		   	: in std_logic;
		tx_serial_data		: out std_logic_vector(NumLHDx2-1 downto 0);
		rx_serial_data		: in  std_logic_vector(NumLHDx2-1 downto 0)   := (others => '0');
		txclkout				: out std_logic_vector(NumLHDx2-1 downto 0);
		rxclkout				: out std_logic_vector(NumLHDx2-1 downto 0);		
		clk_100					: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in				:  in  std_logic_vector(0 downto 0)   := (others => '0')
		);
end component;

-- ##### Duplex Interface #####
component LH_Dx3_Wrap is
	generic(NumChannels:integer:=0;
					TxPLL_Type:string:="ATX";
					SCLK_Select:string:="x24";
					Rate:string:="10G3";
					SIPatterns:boolean:=FALSE);					
	PORT(
		refclk		   		: in std_logic;
		tx_serial_data	: out std_logic_vector(NumLHDx3-1 downto 0);
		rx_serial_data	: in  std_logic_vector(NumLHDx3-1 downto 0)   := (others => '0');
		txclkout				: out std_logic_vector(NumLHDx3-1 downto 0);
		rxclkout				: out std_logic_vector(NumLHDx3-1 downto 0);		
		clk_100					: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in				:  in  std_logic_vector(0 downto 0)   := (others => '0')
		);
end component;

-- ##### Duplex Interface #####
component LH_Dx4_Wrap is
	generic(NumChannels:integer:=0;
					TxPLL_Type:string:="ATX";
					SCLK_Select:string:="x24";
					Rate:string:="10G3";
					SIPatterns:boolean:=FALSE);					
	PORT(
		refclk		   		: in std_logic;
		tx_serial_data	: out std_logic_vector(NumLHDx4-1 downto 0);
		rx_serial_data	: in  std_logic_vector(NumLHDx4-1 downto 0)   := (others => '0'); 
		txclkout				: out std_logic_vector(NumLHDx4-1 downto 0);
		rxclkout				: out std_logic_vector(NumLHDx4-1 downto 0);		
		clk_100					: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in				:  in  std_logic_vector(0 downto 0)   := (others => '0')
		);
end component;

-- ##### Duplex Interface #####
component LH_Dx5_Wrap is
	generic(NumChannels:integer:=0;
					TxPLL_Type:string:="ATX";
					SCLK_Select:string:="x24";
					Rate:string:="10G3";
					SIPatterns:boolean:=FALSE);					
	PORT(
		refclk		   		: in std_logic;
		tx_serial_data	: out std_logic_vector(NumLHDx5-1 downto 0);
		rx_serial_data	: in  std_logic_vector(NumLHDx5-1 downto 0)   := (others => '0');
		txclkout				: out std_logic_vector(NumLHDx5-1 downto 0);
		rxclkout				: out std_logic_vector(NumLHDx5-1 downto 0);		
		clk_100					: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in				:  in  std_logic_vector(0 downto 0)   := (others => '0')
		);
end component;

-- ##### Duplex Interface #####
component LH_Dx6_Wrap is
	generic(NumChannels:integer:=0;
					TxPLL_Type:string:="ATX";
					SCLK_Select:string:="x24";
					Rate:string:="10G3";
					SIPatterns:boolean:=FALSE);					
	PORT(
		refclk		   		: in std_logic;
		tx_serial_data	: out std_logic_vector(NumLHDx6-1 downto 0);
		rx_serial_data	: in  std_logic_vector(NumLHDx6-1 downto 0)   := (others => '0');
		txclkout				: out std_logic_vector(NumLHDx6-1 downto 0);
		rxclkout				: out std_logic_vector(NumLHDx6-1 downto 0);		
		clk_100					: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in				:  in  std_logic_vector(0 downto 0)   := (others => '0')
		);
end component;

-- ##### Duplex Interface #####
component LH_Dx7_Wrap is
	generic(NumChannels:integer:=0;
					TxPLL_Type:string:="ATX";
					SCLK_Select:string:="x24";
					Rate:string:="10G3";
					SIPatterns:boolean:=FALSE);					
	PORT(
		refclk		   		: in std_logic;
		tx_serial_data	: out std_logic_vector(NumLHDx7-1 downto 0);
		rx_serial_data	: in  std_logic_vector(NumLHDx7-1 downto 0)   := (others => '0');
		txclkout				: out std_logic_vector(NumLHDx7-1 downto 0);
		rxclkout				: out std_logic_vector(NumLHDx7-1 downto 0);		
		clk_100					: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in				:  in  std_logic_vector(0 downto 0)   := (others => '0')
		);
end component;

-- ####################################################################
-- ##### Tx Simplex Channels 			#####################################
-- ####################################################################

-- ##### Tx Simplex Interface #####
component LH_Tx0_Wrap is
	generic(NumChannels:integer:=0;
					TxPLL_Type:string:="ATX";
					SCLK_Select:string:="x24";
					Rate:string:="10G3";
					SIPatterns:boolean:=FALSE);					
	PORT(
		refclk		   						: in std_logic;
		tx_serial_data					: out std_logic_vector(NumLHTx0-1 downto 0);
		txclkout								: out std_logic_vector(NumLHTx0-1 downto 0);
		clk_100									: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in								:  in  std_logic_vector(0 downto 0)   := (others => '0');
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0)                     -- waitrequest
		);
end component;

-- ##### Tx Simplex Interface #####
component LH_Tx1_Wrap is
	generic(NumChannels:integer:=0;
					TxPLL_Type:string:="ATX";
					SCLK_Select:string:="x24";
					Rate:string:="10G3";
					SIPatterns:boolean:=FALSE);	
	PORT(
		refclk		   						: in std_logic;
		tx_serial_data					: out std_logic_vector(NumLHTx1-1 downto 0);
		txclkout								: out std_logic_vector(NumLHTx1-1 downto 0);
		clk_100									: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in								:  in  std_logic_vector(0 downto 0)   := (others => '0');
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0)                     -- waitrequest
		);
end component;

-- ##### Tx Simplex Interface #####
component LH_Tx2_Wrap is
	generic(NumChannels:integer:=0;
					TxPLL_Type:string:="ATX";
					SCLK_Select:string:="x24";
					Rate:string:="10G3";
					SIPatterns:boolean:=FALSE);	
	PORT(
		refclk		   						: in std_logic;
		tx_serial_data					: out std_logic_vector(NumLHTx2-1 downto 0);
		txclkout								: out std_logic_vector(NumLHTx2-1 downto 0);
		clk_100									: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in								:  in  std_logic_vector(0 downto 0)   := (others => '0');
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0)                     -- waitrequest
		);
end component;

-- ##### Tx Simplex Interface #####
component LH_Tx3_Wrap is
	generic(NumChannels:integer:=0;
					TxPLL_Type:string:="ATX";
					SCLK_Select:string:="x24";
					Rate:string:="10G3";
					SIPatterns:boolean:=FALSE);	
	PORT(
		refclk		   						: in std_logic;
		tx_serial_data					: out std_logic_vector(NumLHTx3-1 downto 0);
		txclkout								: out std_logic_vector(NumLHTx3-1 downto 0);
		clk_100									: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in								:  in  std_logic_vector(0 downto 0)   := (others => '0');
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0)                     -- waitrequest
		);
end component;

-- ####################################################################
-- ##### Rx Simplex Channels 			#####################################
-- ####################################################################

-- ##### Rx Simplex Interface #####
component LH_Rx0_Wrap is
	generic(NumChannels:integer:=0;
					Rate:string:="10G3");
	PORT(
		refclk		   						: in std_logic;
		rx_serial_data					: in std_logic_vector(NumLHRx0-1 downto 0);
		rxclkout								: out std_logic_vector(NumLHRx0-1 downto 0);		
		clk_100									: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in								:  in  std_logic_vector(0 downto 0)   := (others => '0');
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0)                     -- waitrequest
		);
end component;

-- ##### Rx Simplex Interface #####
component LH_Rx1_Wrap is
	generic(NumChannels:integer:=0;
					Rate:string:="10G3");
	PORT(
		refclk		   						: in std_logic;
		rx_serial_data					: in std_logic_vector(NumLHRx1-1 downto 0);
		rxclkout								: out std_logic_vector(NumLHRx1-1 downto 0);		
		clk_100									: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in								:  in  std_logic_vector(0 downto 0)   := (others => '0');
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0)                     -- waitrequest
		);
end component;

-- ##### Rx Simplex Interface #####
component LH_Rx2_Wrap is
	generic(NumChannels:integer:=0;
					Rate:string:="10G3");
	PORT(
		refclk		   						: in std_logic;
		rx_serial_data					: in std_logic_vector(NumLHRx2-1 downto 0);
		rxclkout								: out std_logic_vector(NumLHRx2-1 downto 0);		
		clk_100									: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in								:  in  std_logic_vector(0 downto 0)   := (others => '0');
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0)                     -- waitrequest
		);
end component;

-- ##### Rx Simplex Interface #####
component LH_Rx3_Wrap is
	generic(NumChannels:integer:=0;
					Rate:string:="10G3");
	PORT(
		refclk		   						: in std_logic;
		rx_serial_data					: in std_logic_vector(NumLHRx3-1 downto 0);
		rxclkout								: out std_logic_vector(NumLHRx3-1 downto 0);		
		clk_100									: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in								:  in  std_logic_vector(0 downto 0)   := (others => '0');
		reconfig_write          : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- write
		reconfig_read           : in  std_logic_vector(0 downto 0)  := (others => 'X'); -- read
		reconfig_address        : in  std_logic_vector(10 downto 0) := (others => 'X'); -- address
		reconfig_writedata      : in  std_logic_vector(31 downto 0) := (others => 'X'); -- writedata
		reconfig_readdata       : out std_logic_vector(31 downto 0);                    -- readdata
		reconfig_waitrequest    : out std_logic_vector(0 downto 0)                     -- waitrequest
		);
end component;

-- ####################################################################
-- ##### GXT Channels 			###########################################
-- ####################################################################

-- ##### GXT Duplex Interface #####
component LH_GT0_Wrap is
	generic( NumAboveChannels:integer:=0;
				   NumMainChannels:integer:=0;    
				   NumBelowChannels:integer:=0;
           Rate: string  := "25G8";
					 SIPatterns:boolean:=FALSE);
	PORT(
		refclk		   		: in std_logic;
		abv_tx_serial_data		: out std_logic_vector(NumLHGT0abv-1 downto 0);
		abv_rx_serial_data		: in  std_logic_vector(NumLHGT0abv-1 downto 0);
		main_tx_serial_data		: out std_logic_vector(NumLHGT0main-1 downto 0);
		main_rx_serial_data		: in  std_logic_vector(NumLHGT0main-1 downto 0);
		blw_tx_serial_data		: out std_logic_vector(NumLHGT0blw-1 downto 0);
		blw_rx_serial_data		: in  std_logic_vector(NumLHGT0blw-1 downto 0);		
		clk_100					: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in				:  in  std_logic_vector(0 downto 0)   := (others => '0')
		);
end component;

-- ##### GXT Duplex Interface #####
component LH_GT1_Wrap is
	generic( NumAboveChannels:integer:=0;
				   NumMainChannels:integer:=0;    
				   NumBelowChannels:integer:=0;
           Rate: string  := "25G8";
					 SIPatterns:boolean:=FALSE);
	PORT(
		refclk		   		: in std_logic;
		abv_tx_serial_data		: out std_logic_vector(NumLHGT1abv-1 downto 0);
		abv_rx_serial_data		: in  std_logic_vector(NumLHGT1abv-1 downto 0);
		main_tx_serial_data		: out std_logic_vector(NumLHGT1main-1 downto 0);
		main_rx_serial_data		: in  std_logic_vector(NumLHGT1main-1 downto 0);
		blw_tx_serial_data		: out std_logic_vector(NumLHGT1blw-1 downto 0);
		blw_rx_serial_data		: in  std_logic_vector(NumLHGT1blw-1 downto 0);		
		clk_100					: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in				:  in  std_logic_vector(0 downto 0)   := (others => '0')
		);
end component;

-- ##### GXT Duplex Interface #####
component LH_GT2_Wrap is
	generic( NumAboveChannels:integer:=0;
				   NumMainChannels:integer:=0;    
				   NumBelowChannels:integer:=0;
           Rate: string  := "25G8";
					 SIPatterns:boolean:=FALSE);
	PORT(
		refclk		   		: in std_logic;
		abv_tx_serial_data		: out std_logic_vector(NumLHGT2abv-1 downto 0);
		abv_rx_serial_data		: in  std_logic_vector(NumLHGT2abv-1 downto 0);
		main_tx_serial_data		: out std_logic_vector(NumLHGT2main-1 downto 0);
		main_rx_serial_data		: in  std_logic_vector(NumLHGT2main-1 downto 0);
		blw_tx_serial_data		: out std_logic_vector(NumLHGT2blw-1 downto 0);
		blw_rx_serial_data		: in  std_logic_vector(NumLHGT2blw-1 downto 0);		
		clk_100					: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in				:  in  std_logic_vector(0 downto 0)   := (others => '0')
		);
end component;

-- ##### GXT Duplex Interface #####
component LH_GT3_Wrap is
	generic( NumAboveChannels:integer:=0;
				   NumMainChannels:integer:=0;    
				   NumBelowChannels:integer:=0;
           Rate: string  := "25G8";
					 SIPatterns:boolean:=FALSE);
	PORT(
		refclk		   		: in std_logic;
		abv_tx_serial_data		: out std_logic_vector(NumLHGT3abv-1 downto 0);
		abv_rx_serial_data		: in  std_logic_vector(NumLHGT3abv-1 downto 0);
		main_tx_serial_data		: out std_logic_vector(NumLHGT3main-1 downto 0);
		main_rx_serial_data		: in  std_logic_vector(NumLHGT3main-1 downto 0);
		blw_tx_serial_data		: out std_logic_vector(NumLHGT3blw-1 downto 0);
		blw_rx_serial_data		: in  std_logic_vector(NumLHGT3blw-1 downto 0);		
		clk_100					: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in				:  in  std_logic_vector(0 downto 0)   := (others => '0')
		);
end component;

-- ##### GXT Duplex Interface #####
component LH_GT4_Wrap is
	generic( NumAboveChannels:integer:=0;
				   NumMainChannels:integer:=0;    
				   NumBelowChannels:integer:=0;
           Rate: string  := "25G8";
					 SIPatterns:boolean:=FALSE);
	PORT(
		refclk		   		: in std_logic;
		abv_tx_serial_data		: out std_logic_vector(NumLHGT4abv-1 downto 0);
		abv_rx_serial_data		: in  std_logic_vector(NumLHGT4abv-1 downto 0);
		main_tx_serial_data		: out std_logic_vector(NumLHGT4main-1 downto 0);
		main_rx_serial_data		: in  std_logic_vector(NumLHGT4main-1 downto 0);
		blw_tx_serial_data		: out std_logic_vector(NumLHGT4blw-1 downto 0);
		blw_rx_serial_data		: in  std_logic_vector(NumLHGT4blw-1 downto 0);		
		clk_100					: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in				:  in  std_logic_vector(0 downto 0)   := (others => '0')
		);
end component;

-- ##### GXT Duplex Interface #####
component LH_GT5_Wrap is
	generic( NumAboveChannels:integer:=0;
				   NumMainChannels:integer:=0;    
				   NumBelowChannels:integer:=0;
           Rate: string  := "25G8";
					 SIPatterns:boolean:=FALSE);
	PORT(
		refclk		   		: in std_logic;
		abv_tx_serial_data		: out std_logic_vector(NumLHGT5abv-1 downto 0);
		abv_rx_serial_data		: in  std_logic_vector(NumLHGT5abv-1 downto 0);
		main_tx_serial_data		: out std_logic_vector(NumLHGT5main-1 downto 0);
		main_rx_serial_data		: in  std_logic_vector(NumLHGT5main-1 downto 0);
		blw_tx_serial_data		: out std_logic_vector(NumLHGT5blw-1 downto 0);
		blw_rx_serial_data		: in  std_logic_vector(NumLHGT5blw-1 downto 0);		
		clk_100					: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in				:  in  std_logic_vector(0 downto 0)   := (others => '0')
		);
end component;

-- ##### GXT Duplex Interface #####
component LH_GT6_Wrap is
	generic( NumAboveChannels:integer:=0;
				   NumMainChannels:integer:=0;    
				   NumBelowChannels:integer:=0;
           Rate: string  := "25G8";
					 SIPatterns:boolean:=FALSE);
	PORT(
		refclk		   		: in std_logic;
		abv_tx_serial_data		: out std_logic_vector(NumLHGT6abv-1 downto 0);
		abv_rx_serial_data		: in  std_logic_vector(NumLHGT6abv-1 downto 0);
		main_tx_serial_data		: out std_logic_vector(NumLHGT6main-1 downto 0);
		main_rx_serial_data		: in  std_logic_vector(NumLHGT6main-1 downto 0);
		blw_tx_serial_data		: out std_logic_vector(NumLHGT6blw-1 downto 0);
		blw_rx_serial_data		: in  std_logic_vector(NumLHGT6blw-1 downto 0);		
		clk_100					: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in				:  in  std_logic_vector(0 downto 0)   := (others => '0')
		);
end component;

-- ##### GXT Duplex Interface #####
component LH_GT7_Wrap is
	generic( NumAboveChannels:integer:=0;
				   NumMainChannels:integer:=0;    
				   NumBelowChannels:integer:=0;
           Rate: string  := "25G8";
					 SIPatterns:boolean:=FALSE);
	PORT(
		refclk		   		: in std_logic;
		abv_tx_serial_data		: out std_logic_vector(NumLHGT7abv-1 downto 0);
		abv_rx_serial_data		: in  std_logic_vector(NumLHGT7abv-1 downto 0);
		main_tx_serial_data		: out std_logic_vector(NumLHGT7main-1 downto 0);
		main_rx_serial_data		: in  std_logic_vector(NumLHGT7main-1 downto 0);
		blw_tx_serial_data		: out std_logic_vector(NumLHGT7blw-1 downto 0);
		blw_rx_serial_data		: in  std_logic_vector(NumLHGT7blw-1 downto 0);		
		clk_100					: in  std_logic_vector(0 downto 0)   := (others => '0');
		Reset_in				:  in  std_logic_vector(0 downto 0)   := (others => '0')
		);
end component;

component Refclk_Select is
	generic(Dx0_refclk_sel, Dx1_refclk_sel, Dx2_refclk_sel, Dx3_refclk_sel, Dx4_refclk_sel, Dx5_refclk_sel, Dx6_refclk_sel, Dx7_refclk_sel :string:="R4NT"; 
					Tx0_refclk_sel,	Tx1_refclk_sel,	Tx2_refclk_sel,	Tx3_refclk_sel :string:="R4NT"; 
					Rx0_refclk_sel,	Rx1_refclk_sel, Rx2_refclk_sel, Rx3_refclk_sel :string:="R4NT";
					GT0_refclk_sel, GT1_refclk_sel, GT2_refclk_sel, GT3_refclk_sel, GT4_refclk_sel, GT5_refclk_sel, GT6_refclk_sel, GT7_refclk_sel :string:="R4NT");
	PORT(
			REFCLK_R4NT, REFCLK_R4NB, REFCLK_R4MT, REFCLK_R4MB, REFCLK_R4LT, REFCLK_R4LB, REFCLK_R4KT, REFCLK_R4KB: in std_logic;		--  	Top right tile
			REFCLK_R4FT, REFCLK_R4FB, REFCLK_R4ET, REFCLK_R4EB, REFCLK_R4DT, REFCLK_R4DB, REFCLK_R4CT, REFCLK_R4CB: in std_logic;		--  	Bottom right tile		
			REFCLK_L1NT, REFCLK_L1NB, REFCLK_L1MT, REFCLK_L1MB, REFCLK_L1LT, REFCLK_L1LB,	REFCLK_L1KT, REFCLK_L1KB: in std_logic;		--  	Top left tile
			REFCLK_L1FT, REFCLK_L1FB, REFCLK_L1ET, REFCLK_L1EB, REFCLK_L1DT, REFCLK_L1DB,	REFCLK_L1CT, REFCLK_L1CB: in std_logic;		--  	Bottom left tile		
			Dx0_refclk, Dx1_refclk, Dx2_refclk, Dx3_refclk, Dx4_refclk, Dx5_refclk, Dx6_refclk, Dx7_refclk : out std_logic;
			Tx0_refclk, Tx1_refclk, Tx2_refclk, Tx3_refclk : out std_logic;
			Rx0_refclk, Rx1_refclk, Rx2_refclk, Rx3_refclk : out std_logic;
			GT0_refclk, GT1_refclk, GT2_refclk, GT3_refclk, GT4_refclk, GT5_refclk, GT6_refclk, GT7_refclk : out std_logic    
		);
end component;

                                                         
begin                                                                                                                                                                                            
-- ################################################################################################################
-- ##### Start RTL Here ###########################################################################################
-- ################################################################################################################

		reconfig_write          <= (others => '0');
		reconfig_read           <= (others => '0');
		reconfig_address        <= (others => '0');
		reconfig_writedata      <= (others => '0');

-- ####################################################################
-- ##### Duplex Channels 			#########################################
-- ####################################################################

-- ##### Duplex Interface #####
Gen_LHDx0:if NumLHDx0 > 0 generate
	LHDx0: LH_Dx0_Wrap
	Generic Map(NumLHDx0,
							LHDx0_TxPLL,
							LHDx0_SCLK,
							LHDx0_Rate,
							LHDx0_EnSIPatterns)
	    port map
	    (   
			refclk		    		=> LHDx0_refclk,
			tx_serial_data  	=> Tx_LHDx0(NumLHDx0-1 downto 0),
			rx_serial_data  	=> Rx_LHDx0(NumLHDx0-1 downto 0),
			txclkout					=> LHDx0_txclkout(NumLHDx0-1 downto 0),
			rxclkout					=> LHDx0_rxclkout(NumLHDx0-1 downto 0),
			clk_100         	=> clk_100,
			Reset_in        	=> MasterReset
		); 
end generate Gen_LHDx0;

-- ##### Duplex Interface #####
Gen_LHDx1:if NumLHDx1 > 0 generate
	LHDx1: LH_Dx1_Wrap
	Generic Map(NumLHDx1,
							LHDx1_TxPLL,
							LHDx1_SCLK,
							LHDx1_Rate,
							LHDx1_EnSIPatterns)
	    port map
	    (   
			refclk		    		=> LHDx1_refclk,
			tx_serial_data  	=> Tx_LHDx1(NumLHDx1-1 downto 0),
			rx_serial_data  	=> Rx_LHDx1(NumLHDx1-1 downto 0),
			txclkout					=> LHDx1_txclkout(NumLHDx1-1 downto 0),
			rxclkout					=> LHDx1_rxclkout(NumLHDx1-1 downto 0),
			clk_100         	=> clk_100,
			Reset_in        	=> MasterReset
		); 
end generate Gen_LHDx1;	

-- ##### Duplex Interface #####
Gen_LHDx2:if NumLHDx2 > 0 generate
	LHDx2: LH_Dx2_Wrap
	Generic Map(NumLHDx2,
							LHDx2_TxPLL,
							LHDx2_SCLK,
							LHDx2_Rate,
							LHDx2_EnSIPatterns)
	    port map
	    (   
			refclk		    		=> LHDx2_refclk,
			tx_serial_data  	=> Tx_LHDx2(NumLHDx2-1 downto 0),
			rx_serial_data  	=> Rx_LHDx2(NumLHDx2-1 downto 0),
			txclkout					=> LHDx2_txclkout(NumLHDx2-1 downto 0),
			rxclkout					=> LHDx2_rxclkout(NumLHDx2-1 downto 0),
			clk_100         	=> clk_100,
			Reset_in        	=> MasterReset
		); 
end generate Gen_LHDx2;	

-- ##### Duplex Interface #####
Gen_LHDx3:if NumLHDx3 > 0 generate
	LHDx3: LH_Dx3_Wrap
	Generic Map(NumLHDx3,
							LHDx3_TxPLL,
							LHDx3_SCLK,
							LHDx3_Rate,
							LHDx3_EnSIPatterns)
	    port map
	    (   
			refclk		    		=> LHDx3_refclk,
			tx_serial_data  	=> Tx_LHDx3(NumLHDx3-1 downto 0),
			rx_serial_data  	=> Rx_LHDx3(NumLHDx3-1 downto 0),
			txclkout					=> LHDx3_txclkout(NumLHDx3-1 downto 0),
			rxclkout					=> LHDx3_rxclkout(NumLHDx3-1 downto 0),
			clk_100         	=> clk_100,
			Reset_in        	=> MasterReset
		); 
end generate Gen_LHDx3;	

-- ##### Duplex Interface #####
Gen_LHDx4:if NumLHDx4 > 0 generate
	LHDx4: LH_Dx4_Wrap
	Generic Map(NumLHDx4,
							LHDx4_TxPLL,
							LHDx4_SCLK,
							LHDx4_Rate,
							LHDx4_EnSIPatterns)
	    port map
	    (   
			refclk		    		=> LHDx4_refclk,
			tx_serial_data  	=> Tx_LHDx4(NumLHDx4-1 downto 0),
			rx_serial_data  	=> Rx_LHDx4(NumLHDx4-1 downto 0),
			txclkout					=> LHDx4_txclkout(NumLHDx4-1 downto 0),
			rxclkout					=> LHDx4_rxclkout(NumLHDx4-1 downto 0),
			clk_100         	=> clk_100,
			Reset_in        	=> MasterReset
		); 
end generate Gen_LHDx4;	

-- ##### Duplex Interface #####
Gen_LHDx5:if NumLHDx5 > 0 generate
	LHDx5: LH_Dx5_Wrap
	Generic Map(NumLHDx5,
							LHDx5_TxPLL,
							LHDx5_SCLK,
							LHDx5_Rate,
							LHDx5_EnSIPatterns)
	    port map
	    (   
			refclk		    		=> LHDx5_refclk,
			tx_serial_data  	=> Tx_LHDx5(NumLHDx5-1 downto 0),
			rx_serial_data  	=> Rx_LHDx5(NumLHDx5-1 downto 0),
			txclkout					=> LHDx5_txclkout(NumLHDx5-1 downto 0),
			rxclkout					=> LHDx5_rxclkout(NumLHDx5-1 downto 0),
			clk_100         	=> clk_100,
			Reset_in        	=> MasterReset
		); 
end generate Gen_LHDx5;	

-- ##### Duplex Interface #####
Gen_LHDx6:if NumLHDx6 > 0 generate
	LHDx6: LH_Dx6_Wrap
	Generic Map(NumLHDx6,
							LHDx6_TxPLL,
							LHDx6_SCLK,
							LHDx6_Rate,
							LHDx6_EnSIPatterns)
	    port map
	    (   
			refclk		    		=> LHDx6_refclk,
			tx_serial_data  	=> Tx_LHDx6(NumLHDx6-1 downto 0),
			rx_serial_data  	=> Rx_LHDx6(NumLHDx6-1 downto 0),
			txclkout					=> LHDx6_txclkout(NumLHDx6-1 downto 0),
			rxclkout					=> LHDx6_rxclkout(NumLHDx6-1 downto 0),
			clk_100         	=> clk_100,
			Reset_in        	=> MasterReset
		); 
end generate Gen_LHDx6;	

-- ##### Duplex Interface #####
Gen_LHDx7:if NumLHDx7 > 0 generate
	LHDx7: LH_Dx7_Wrap
	Generic Map(NumLHDx7,
							LHDx7_TxPLL,
							LHDx7_SCLK,
							LHDx7_Rate,
							LHDx7_EnSIPatterns)
	    port map
	    (   
			refclk		    		=> LHDx7_refclk,
			tx_serial_data  	=> Tx_LHDx7(NumLHDx7-1 downto 0),
			rx_serial_data  	=> Rx_LHDx7(NumLHDx7-1 downto 0),
			txclkout					=> LHDx7_txclkout(NumLHDx7-1 downto 0),
			rxclkout					=> LHDx7_rxclkout(NumLHDx7-1 downto 0),
			clk_100         	=> clk_100,
			Reset_in        	=> MasterReset
		); 
end generate Gen_LHDx7;	

-- ####################################################################
-- ##### Simplex Tx Channels 			#####################################
-- ####################################################################

-- ##### Tx Simplex Interface #####
Gen_LHTx0:if NumLHTx0 > 0 generate
	LHTx0: LH_Tx0_Wrap
	Generic Map(NumLHTx0,
							LHTx0_TxPLL,
							LHTx0_SCLK,
							LHTx0_Rate,
							LHTx0_EnSIPatterns)
	    port map
	    (   
			refclk		    				=> LHTx0_refclk,
			tx_serial_data  			=> Tx_LHTx0(NumLHTx0-1 downto 0),
			txclkout							=> LHTx0_txclkout(NumLHTx0-1 downto 0),
			clk_100         			=> clk_100,
			Reset_in        			=> MasterReset,
  		reconfig_write        => reconfig_write    ,	--(others => '0'),
	  	reconfig_read         => reconfig_read     ,	--(others => '0'),
	  	reconfig_address      => reconfig_address  ,	--(others => '0'),
	  	reconfig_writedata    => reconfig_writedata,	--(others => '0'),
		  reconfig_readdata     => open,
		  reconfig_waitrequest	=> open
		); 
end generate Gen_LHTx0;

-- ##### Tx Simplex Interface #####
Gen_LHTx1:if NumLHTx1 > 0 generate
	LHTx1: LH_Tx1_Wrap
	Generic Map(NumLHTx1,
							LHTx1_TxPLL,
							LHTx1_SCLK,
							LHTx1_Rate,
							LHTx1_EnSIPatterns)
	    port map
	    (   
			refclk		    				=> LHTx1_refclk,
			tx_serial_data  			=> Tx_LHTx1(NumLHTx1-1 downto 0),
			txclkout							=> LHTx1_txclkout(NumLHTx1-1 downto 0),
			clk_100         			=> clk_100,
			Reset_in        			=> MasterReset,
  		reconfig_write        => reconfig_write    ,	--(others => '0'),
	  	reconfig_read         => reconfig_read     ,	--(others => '0'),
	  	reconfig_address      => reconfig_address  ,	--(others => '0'),
	  	reconfig_writedata    => reconfig_writedata,	--(others => '0'),
		  reconfig_readdata     => open,
		  reconfig_waitrequest	=> open
		); 
end generate Gen_LHTx1;

-- ##### Tx Simplex Interface #####
Gen_LHTx2:if NumLHTx2 > 0 generate
	LHTx2: LH_Tx2_Wrap
	Generic Map(NumLHTx2,
							LHTx2_TxPLL,
							LHTx2_SCLK,
							LHTx2_Rate,
							LHTx2_EnSIPatterns)
	    port map
	    (   
			refclk		    				=> LHTx2_refclk,
			tx_serial_data  			=> Tx_LHTx2(NumLHTx2-1 downto 0),
			txclkout							=> LHTx2_txclkout(NumLHTx2-1 downto 0),
			clk_100         			=> clk_100,
			Reset_in        			=> MasterReset,
  		reconfig_write        => reconfig_write    ,	--(others => '0'),
	  	reconfig_read         => reconfig_read     ,	--(others => '0'),
	  	reconfig_address      => reconfig_address  ,	--(others => '0'),
	  	reconfig_writedata    => reconfig_writedata,	--(others => '0'),
		  reconfig_readdata     => open,
		  reconfig_waitrequest	=> open
		); 
end generate Gen_LHTx2;

-- ##### Tx Simplex Interface #####
Gen_LHTx3:if NumLHTx3 > 0 generate
	LHTx3: LH_Tx3_Wrap
	Generic Map(NumLHTx3,
							LHTx3_TxPLL,
							LHTx3_SCLK,
							LHTx3_Rate,
							LHTx3_EnSIPatterns)
	    port map
	    (   
			refclk		    				=> LHTx3_refclk,
			tx_serial_data  			=> Tx_LHTx3(NumLHTx3-1 downto 0),
			txclkout							=> LHTx3_txclkout(NumLHTx3-1 downto 0),
			clk_100         			=> clk_100,
			Reset_in        			=> MasterReset,
  		reconfig_write        => reconfig_write    ,	--(others => '0'),
	  	reconfig_read         => reconfig_read     ,	--(others => '0'),
	  	reconfig_address      => reconfig_address  ,	--(others => '0'),
	  	reconfig_writedata    => reconfig_writedata,	--(others => '0'),
		  reconfig_readdata     => open,
		  reconfig_waitrequest	=> open
		); 
end generate Gen_LHTx3;

-- ####################################################################
-- ##### Simplex Rx Only Channels 			###############################
-- ####################################################################

-- ##### Rx Simplex Interface #####
Gen_LHRx0:if NumLHRx0 > 0 generate
	LHRx0: LH_Rx0_Wrap
	Generic Map(NumLHRx0,
							LHRx0_Rate)
	    port map
	    (   
			refclk		    				=> LHRx0_refclk,
			rx_serial_data  			=> Rx_LHRx0(NumLHRx0-1 downto 0),
			rxclkout							=> LHRx0_rxclkout(NumLHRx0-1 downto 0),
			clk_100         			=> clk_100,
			Reset_in        			=> MasterReset,
  		reconfig_write        => reconfig_write    ,	--(others => '0'),
	  	reconfig_read         => reconfig_read     ,	--(others => '0'),
	  	reconfig_address      => reconfig_address  ,	--(others => '0'),
	  	reconfig_writedata    => reconfig_writedata,	--(others => '0'),
		  reconfig_readdata     => open,
		  reconfig_waitrequest	=> open
		); 
end generate Gen_LHRx0;

-- ##### Rx Simplex Interface #####
Gen_LHRx1:if NumLHRx1 > 0 generate
	LHRx1: LH_Rx1_Wrap
	Generic Map(NumLHRx1,
							LHRx1_Rate)
	    port map
	    (   
			refclk		    				=> LHRx1_refclk,
			rx_serial_data  			=> Rx_LHRx1(NumLHRx1-1 downto 0),
			rxclkout							=> LHRx1_rxclkout(NumLHRx1-1 downto 0),
			clk_100         			=> clk_100,
			Reset_in        			=> MasterReset,
  		reconfig_write        => reconfig_write    ,	--(others => '0'),
	  	reconfig_read         => reconfig_read     ,	--(others => '0'),
	  	reconfig_address      => reconfig_address  ,	--(others => '0'),
	  	reconfig_writedata    => reconfig_writedata,	--(others => '0'),
		  reconfig_readdata     => open,
		  reconfig_waitrequest	=> open
		); 
end generate Gen_LHRx1;

-- ##### Rx Simplex Interface #####
Gen_LHRx2:if NumLHRx2 > 0 generate
	LHRx2: LH_Rx2_Wrap
	Generic Map(NumLHRx2,
							LHRx2_Rate)
	    port map
	    (   
			refclk		    				=> LHRx2_refclk,
			rx_serial_data  			=> Rx_LHRx0(NumLHRx0-1 downto 0),
			rxclkout							=> LHRx0_rxclkout(NumLHRx0-1 downto 0),
			clk_100         			=> clk_100,
			Reset_in        			=> MasterReset,
  		reconfig_write        => reconfig_write    ,	--(others => '0'),
	  	reconfig_read         => reconfig_read     ,	--(others => '0'),
	  	reconfig_address      => reconfig_address  ,	--(others => '0'),
	  	reconfig_writedata    => reconfig_writedata,	--(others => '0'),
		  reconfig_readdata     => open,
		  reconfig_waitrequest	=> open
		); 
end generate Gen_LHRx2;

-- ##### Rx Simplex Interface #####
Gen_LHRx3:if NumLHRx3 > 0 generate
	LHRx3: LH_Rx3_Wrap
	Generic Map(NumLHRx3,
							LHRx3_Rate)
	    port map
	    (   
			refclk		    				=> LHRx3_refclk,
			rx_serial_data  			=> Rx_LHRx1(NumLHRx1-1 downto 0),
			rxclkout							=> LHRx1_rxclkout(NumLHRx1-1 downto 0),
			clk_100         			=> clk_100,
			Reset_in        			=> MasterReset,
  		reconfig_write        => reconfig_write    ,	--(others => '0'),
	  	reconfig_read         => reconfig_read     ,	--(others => '0'),
	  	reconfig_address      => reconfig_address  ,	--(others => '0'),
	  	reconfig_writedata    => reconfig_writedata,	--(others => '0'),
		  reconfig_readdata     => open,
		  reconfig_waitrequest	=> open
		); 
end generate Gen_LHRx3;

-- ####################################################################
-- ##### GXT Channels 			###########################################
-- ####################################################################

-- ##### GXT Duplex Interface #####
Gen_LHGT0:if (NumLHGT0abv + NumLHGT0main + NumLHGT0blw) > 0 generate
	LHGT0: LH_GT0_Wrap
	Generic Map(NumLHGT0abv,NumLHGT0main,NumLHGT0blw,LHGT0_Rate,LHGT0_EnSIPatterns)
	    port map
	    (   
			refclk		    	=> LHGT0_refclk,
			abv_tx_serial_data		=> 	Tx_LHGT0abv(NumLHGT0abv-1 downto 0),
			abv_rx_serial_data		=> 	Rx_LHGT0abv(NumLHGT0abv-1 downto 0),
			main_tx_serial_data		=> 	Tx_LHGT0main(NumLHGT0main-1 downto 0),
			main_rx_serial_data		=> 	Rx_LHGT0main(NumLHGT0main-1 downto 0),
			blw_tx_serial_data		=> 	Tx_LHGT0blw(NumLHGT0blw-1 downto 0),
			blw_rx_serial_data		=> 	Rx_LHGT0blw(NumLHGT0blw-1 downto 0),
      clk_100         	=> clk_100,
			Reset_in        	=> MasterReset
		); 
end generate Gen_LHGT0;

-- ##### GXT Duplex Interface #####
Gen_LHGT1:if (NumLHGT1abv + NumLHGT1main + NumLHGT1blw) > 0 generate
	LHGT1: LH_GT1_Wrap
	Generic Map(NumLHGT1abv,NumLHGT1main,NumLHGT1blw,LHGT1_Rate,LHGT0_EnSIPatterns)
	    port map
	    (   
			refclk		    	=> LHGT1_refclk,
			abv_tx_serial_data		=> 	Tx_LHGT1abv(NumLHGT1abv-1 downto 0),
			abv_rx_serial_data		=> 	Rx_LHGT1abv(NumLHGT1abv-1 downto 0),
			main_tx_serial_data		=> 	Tx_LHGT1main(NumLHGT1main-1 downto 0),
			main_rx_serial_data		=> 	Rx_LHGT1main(NumLHGT1main-1 downto 0),
			blw_tx_serial_data		=> 	Tx_LHGT1blw(NumLHGT1blw-1 downto 0),
			blw_rx_serial_data		=> 	Rx_LHGT1blw(NumLHGT1blw-1 downto 0),
      clk_100         	=> clk_100,
			Reset_in        	=> MasterReset
		); 
end generate Gen_LHGT1;

-- ##### GXT Duplex Interface #####
Gen_LHGT2:if (NumLHGT2abv + NumLHGT2main + NumLHGT2blw) > 0 generate
	LHGT2: LH_GT2_Wrap
	Generic Map(NumLHGT2abv,NumLHGT2main,NumLHGT2blw,LHGT2_Rate,LHGT0_EnSIPatterns)
	    port map
	    (   
			refclk		    	=> LHGT2_refclk,
			abv_tx_serial_data		=> 	Tx_LHGT2abv(NumLHGT2abv-1 downto 0),
			abv_rx_serial_data		=> 	Rx_LHGT2abv(NumLHGT2abv-1 downto 0),
			main_tx_serial_data		=> 	Tx_LHGT2main(NumLHGT2main-1 downto 0),
			main_rx_serial_data		=> 	Rx_LHGT2main(NumLHGT2main-1 downto 0),
			blw_tx_serial_data		=> 	Tx_LHGT2blw(NumLHGT2blw-1 downto 0),
			blw_rx_serial_data		=> 	Rx_LHGT2blw(NumLHGT2blw-1 downto 0),
      clk_100         	=> clk_100,
			Reset_in        	=> MasterReset
		); 
end generate Gen_LHGT2;

-- ##### GXT Duplex Interface #####
Gen_LHGT3:if (NumLHGT3abv + NumLHGT3main + NumLHGT3blw) > 0 generate
	LHGT3: LH_GT3_Wrap
	Generic Map(NumLHGT3abv,NumLHGT3main,NumLHGT3blw,LHGT3_Rate,LHGT0_EnSIPatterns)
	    port map
	    (   
			refclk		    	=> LHGT3_refclk,
			abv_tx_serial_data		=> 	Tx_LHGT3abv(NumLHGT3abv-1 downto 0),
			abv_rx_serial_data		=> 	Rx_LHGT3abv(NumLHGT3abv-1 downto 0),
			main_tx_serial_data		=> 	Tx_LHGT3main(NumLHGT3main-1 downto 0),
			main_rx_serial_data		=> 	Rx_LHGT3main(NumLHGT3main-1 downto 0),
			blw_tx_serial_data		=> 	Tx_LHGT3blw(NumLHGT3blw-1 downto 0),
			blw_rx_serial_data		=> 	Rx_LHGT3blw(NumLHGT3blw-1 downto 0),
      clk_100         	=> clk_100,
			Reset_in        	=> MasterReset
		); 
end generate Gen_LHGT3;

-- ##### GXT Duplex Interface #####
Gen_LHGT4:if (NumLHGT4abv + NumLHGT4main + NumLHGT4blw) > 0 generate
	LHGT4: LH_GT4_Wrap
	Generic Map(NumLHGT4abv,NumLHGT4main,NumLHGT4blw,LHGT4_Rate,LHGT0_EnSIPatterns)
	    port map
	    (   
			refclk		    	=> LHGT4_refclk,
			abv_tx_serial_data		=> 	Tx_LHGT4abv(NumLHGT4abv-1 downto 0),
			abv_rx_serial_data		=> 	Rx_LHGT4abv(NumLHGT4abv-1 downto 0),
			main_tx_serial_data		=> 	Tx_LHGT4main(NumLHGT4main-1 downto 0),
			main_rx_serial_data		=> 	Rx_LHGT4main(NumLHGT4main-1 downto 0),
			blw_tx_serial_data		=> 	Tx_LHGT4blw(NumLHGT4blw-1 downto 0),
			blw_rx_serial_data		=> 	Rx_LHGT4blw(NumLHGT4blw-1 downto 0),
      clk_100         	=> clk_100,
			Reset_in        	=> MasterReset
		); 
end generate Gen_LHGT4;

-- ##### GXT Duplex Interface ######
Gen_LHGT5:if (NumLHGT5abv + NumLHGT5main + NumLHGT5blw) > 0 generate
	LHGT5: LH_GT5_Wrap
	Generic Map(NumLHGT5abv,NumLHGT5main,NumLHGT5blw,LHGT5_Rate,LHGT5_EnSIPatterns)
	    port map
	    (   
			refclk		    	=> LHGT5_refclk,
			abv_tx_serial_data		=> 	Tx_LHGT5abv(NumLHGT5abv-1 downto 0),
			abv_rx_serial_data		=> 	Rx_LHGT5abv(NumLHGT5abv-1 downto 0),
			main_tx_serial_data		=> 	Tx_LHGT5main(NumLHGT5main-1 downto 0),
			main_rx_serial_data		=> 	Rx_LHGT5main(NumLHGT5main-1 downto 0),
			blw_tx_serial_data		=> 	Tx_LHGT5blw(NumLHGT5blw-1 downto 0),
			blw_rx_serial_data		=> 	Rx_LHGT5blw(NumLHGT5blw-1 downto 0),
      clk_100         	=> clk_100,
			Reset_in        	=> MasterReset
		); 
end generate Gen_LHGT5;

-- ##### GXT Duplex Interface #####
Gen_LHGT6:if (NumLHGT6abv + NumLHGT6main + NumLHGT6blw) > 0 generate
	LHGT6: LH_GT6_Wrap
	Generic Map(NumLHGT6abv,NumLHGT6main,NumLHGT6blw,LHGT6_Rate,LHGT6_EnSIPatterns)
	    port map
	    (   
			refclk		    	=> LHGT6_refclk,
			abv_tx_serial_data		=> 	Tx_LHGT6abv(NumLHGT6abv-1 downto 0),
			abv_rx_serial_data		=> 	Rx_LHGT6abv(NumLHGT6abv-1 downto 0),
			main_tx_serial_data		=> 	Tx_LHGT6main(NumLHGT6main-1 downto 0),
			main_rx_serial_data		=> 	Rx_LHGT6main(NumLHGT6main-1 downto 0),
			blw_tx_serial_data		=> 	Tx_LHGT6blw(NumLHGT6blw-1 downto 0),
			blw_rx_serial_data		=> 	Rx_LHGT6blw(NumLHGT6blw-1 downto 0),
      clk_100         	=> clk_100,
			Reset_in        	=> MasterReset
		); 
end generate Gen_LHGT6;

-- ##### GXT Duplex Interface #####
Gen_LHGT7:if (NumLHGT7abv + NumLHGT7main + NumLHGT7blw) > 0 generate
	LHGT7: LH_GT7_Wrap
	Generic Map(NumLHGT7abv,NumLHGT7main,NumLHGT7blw,LHGT7_Rate,LHGT7_EnSIPatterns)
	    port map
	    (   
			refclk		    	=> LHGT7_refclk,
			abv_tx_serial_data		=> 	Tx_LHGT7abv(NumLHGT7abv-1 downto 0),
			abv_rx_serial_data		=> 	Rx_LHGT7abv(NumLHGT7abv-1 downto 0),
			main_tx_serial_data		=> 	Tx_LHGT7main(NumLHGT7main-1 downto 0),
			main_rx_serial_data		=> 	Rx_LHGT7main(NumLHGT7main-1 downto 0),
			blw_tx_serial_data		=> 	Tx_LHGT7blw(NumLHGT7blw-1 downto 0),
			blw_rx_serial_data		=> 	Rx_LHGT7blw(NumLHGT7blw-1 downto 0),
      clk_100         	=> clk_100,
			Reset_in        	=> MasterReset
		); 
end generate Gen_LHGT7;


-- ####################################################################                 
-- ##### Power On Reset 			#########################################
-- ####################################################################                 

process(clk_100)
begin
	if rising_edge (clk_100(0)) then
		if ResetCount = 0 then
			PowerOnReset <= '0';
		else
			PowerOnReset <= '1';
		  	ResetCount <= ResetCount - 1;
		end if;
	end if;
end process;

PowerOnReset_n <= not PowerOnReset;	
ResetPB <= not USER_PB(0);	--invert pushbutton	
MasterReset(0) <= PowerOnReset OR ResetPB;  -- Allow POR and PB operation


-- ####################################################################                 
-- ##### REFCLK Select 			###########################################
-- ####################################################################  

refsel:Refclk_Select
	Generic Map(LHDx0_refclk_sel, LHDx1_refclk_sel, LHDx2_refclk_sel, LHDx3_refclk_sel, LHDx4_refclk_sel, LHDx5_refclk_sel, LHDx6_refclk_sel, LHDx7_refclk_sel,
							LHTx0_refclk_sel, LHTx1_refclk_sel, LHTx2_refclk_sel, LHTx3_refclk_sel,
							LHRx0_refclk_sel, LHRx1_refclk_sel, LHRx2_refclk_sel, LHRx3_refclk_sel,
							LHGT0_refclk_sel, LHGT1_refclk_sel, LHGT2_refclk_sel, LHGT3_refclk_sel, LHGT4_refclk_sel, LHGT5_refclk_sel, LHGT6_refclk_sel, LHGT7_refclk_sel)
	port map(
--		### Inputs ###
--  	Top right tile
			REFCLK_R4NT => REFCLK_R4NT,
			REFCLK_R4NB => REFCLK_R4NB,
			REFCLK_R4MT => REFCLK_R4MT,
			REFCLK_R4MB => REFCLK_R4MB,
			REFCLK_R4LT => REFCLK_R4LT,
			REFCLK_R4LB => REFCLK_R4LB,
			REFCLK_R4KT => REFCLK_R4KT,
			REFCLK_R4KB => REFCLK_R4KB,
			
--  	Bottom right tile					
			REFCLK_R4FT => REFCLK_R4FT,
			REFCLK_R4FB => REFCLK_R4FB,
			REFCLK_R4ET => REFCLK_R4ET,
			REFCLK_R4EB => REFCLK_R4EB,
			REFCLK_R4DT => REFCLK_R4DT,
			REFCLK_R4DB => REFCLK_R4DB,
			REFCLK_R4CT => REFCLK_R4CT,
			REFCLK_R4CB => REFCLK_R4CB,
			
--  	Top left tile
			REFCLK_L1NT => REFCLK_L1NT,
			REFCLK_L1NB => REFCLK_L1NB,
			REFCLK_L1MT => REFCLK_L1MT,
			REFCLK_L1MB => REFCLK_L1MB,
			REFCLK_L1LT => REFCLK_L1LT,
			REFCLK_L1LB => REFCLK_L1LB,
			REFCLK_L1KT => REFCLK_L1KT,
			REFCLK_L1KB => REFCLK_L1KB,
			
--  	Bottom left tile		
			REFCLK_L1FT => REFCLK_L1FT,
			REFCLK_L1FB => REFCLK_L1FB,
			REFCLK_L1ET => REFCLK_L1ET,
			REFCLK_L1EB => REFCLK_L1EB,
			REFCLK_L1DT => REFCLK_L1DT,
			REFCLK_L1DB => REFCLK_L1DB,
			REFCLK_L1CT => REFCLK_L1CT,
			REFCLK_L1CB => REFCLK_L1CB,
			
--		### Ouputs ###			
			Dx0_refclk => LHDx0_refclk,
			Dx1_refclk => LHDx1_refclk,
			Dx2_refclk => LHDx2_refclk,
			Dx3_refclk => LHDx3_refclk,
			Dx4_refclk => LHDx4_refclk,
			Dx5_refclk => LHDx5_refclk,
			Dx6_refclk => LHDx6_refclk,
			Dx7_refclk => LHDx7_refclk,
			
			Tx0_refclk => LHTx0_refclk,
			Tx1_refclk => LHTx1_refclk,
			Tx2_refclk => LHTx2_refclk,
			Tx3_refclk => LHTx3_refclk,

			Rx0_refclk => LHRx0_refclk,
			Rx1_refclk => LHRx1_refclk,
			Rx2_refclk => LHRx2_refclk,
			Rx3_refclk => LHRx3_refclk,
			
			GT0_refclk => LHGT0_refclk,
			GT1_refclk => LHGT1_refclk,
			GT2_refclk => LHGT2_refclk,
			GT3_refclk => LHGT3_refclk,
			GT4_refclk => LHGT4_refclk,
			GT5_refclk => LHGT5_refclk,
			GT6_refclk => LHGT6_refclk,
			GT7_refclk => LHGT7_refclk		
		);





end rtl;
