--######################################################################################################
-- FILE          : refclk_select
-- RELATED FILES :
-- DESCRIPTION   : This is just a great big generate block.
--               : I dont want physical RTL (mux) on the REFCLK because that gets implemented in the fabric and adds jitter. 
--               : A generate statement is used to select the REFCLK for each group 
--               : 
--               : 
--               :
-- AUTHOR        : James Murray 
-- DEPARTMENT    : European Regional Application Engineering
-- COMPANY       : Intel PSG
--######################################################################################################

library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_unsigned.all;

entity refclk_select is
	generic(Dx0_refclk_sel, Dx1_refclk_sel, Dx2_refclk_sel, Dx3_refclk_sel,	Dx4_refclk_sel, Dx5_refclk_sel, Dx6_refclk_sel, Dx7_refclk_sel :string:="R4NT";
					Tx0_refclk_sel, Tx1_refclk_sel, Tx2_refclk_sel,	Tx3_refclk_sel:string:="R4NT";
					Rx0_refclk_sel, Rx1_refclk_sel, Rx2_refclk_sel,	Rx3_refclk_sel:string:="R4NT";
					GT0_refclk_sel, GT1_refclk_sel, GT2_refclk_sel, GT3_refclk_sel, GT4_refclk_sel, GT5_refclk_sel, GT6_refclk_sel, GT7_refclk_sel :string:="R4NT");
	port(           
			REFCLK_R4NT, REFCLK_R4NB, REFCLK_R4MT, REFCLK_R4MB, REFCLK_R4LT, REFCLK_R4LB, REFCLK_R4KT, REFCLK_R4KB: in std_logic;		-- Top right tile		
			REFCLK_R4FT, REFCLK_R4FB, REFCLK_R4ET, REFCLK_R4EB, REFCLK_R4DT, REFCLK_R4DB, REFCLK_R4CT, REFCLK_R4CB: in std_logic;		-- Bottom right tile
			REFCLK_L1NT, REFCLK_L1NB, REFCLK_L1MT, REFCLK_L1MB, REFCLK_L1LT, REFCLK_L1LB,	REFCLK_L1KT, REFCLK_L1KB: in std_logic;		-- Top left tile
			REFCLK_L1FT, REFCLK_L1FB, REFCLK_L1ET, REFCLK_L1EB, REFCLK_L1DT, REFCLK_L1DB, REFCLK_L1CT, REFCLK_L1CB: in std_logic;		-- Bottom left tile		
			
			Dx0_refclk, Dx1_refclk, Dx2_refclk, Dx3_refclk, Dx4_refclk, Dx5_refclk, Dx6_refclk, Dx7_refclk : out std_logic;
			Tx0_refclk, Tx1_refclk, Tx2_refclk, Tx3_refclk : out std_logic;
			Rx0_refclk, Rx1_refclk, Rx2_refclk, Rx3_refclk : out std_logic;
			GT0_refclk, GT1_refclk, GT2_refclk, GT3_refclk, GT4_refclk, GT5_refclk, GT6_refclk, GT7_refclk : out std_logic
	);
end entity refclk_select;


architecture rtl of refclk_select is


begin
--##############################################################
--## Dx0_refclk_select  ########################################
--##############################################################

Gen_Dx0_refclk:
-- Top right tile.
	if Dx0_refclk_sel = "R4NT" generate
		Dx0_refclk <= REFCLK_R4NT; 
	elsif Dx0_refclk_sel = "R4NB" generate
		Dx0_refclk <= REFCLK_R4NB; 
	elsif Dx0_refclk_sel = "R4MT" generate
		Dx0_refclk <= REFCLK_R4MT; 
	elsif Dx0_refclk_sel = "R4MB" generate
		Dx0_refclk <= REFCLK_R4MB; 
	elsif Dx0_refclk_sel = "R4LT" generate
		Dx0_refclk <= REFCLK_R4LT; 
	elsif Dx0_refclk_sel = "R4LB" generate
		Dx0_refclk <= REFCLK_R4LB; 
	elsif Dx0_refclk_sel = "R4KT" generate
		Dx0_refclk <= REFCLK_R4KT; 
	elsif Dx0_refclk_sel = "R4KB" generate
		Dx0_refclk <= REFCLK_R4KB; 

-- Bottom right tile.
	elsif Dx0_refclk_sel = "R4FT" generate
		Dx0_refclk <= REFCLK_R4FT; 
	elsif Dx0_refclk_sel = "R4FB" generate
		Dx0_refclk <= REFCLK_R4FB; 
	elsif Dx0_refclk_sel = "R4ET" generate
		Dx0_refclk <= REFCLK_R4ET; 
	elsif Dx0_refclk_sel = "R4EB" generate
		Dx0_refclk <= REFCLK_R4EB; 
	elsif Dx0_refclk_sel = "R4DT" generate
		Dx0_refclk <= REFCLK_R4DT; 
	elsif Dx0_refclk_sel = "R4DB" generate
		Dx0_refclk <= REFCLK_R4DB; 
	elsif Dx0_refclk_sel = "R4CT" generate
		Dx0_refclk <= REFCLK_R4CT; 
	elsif Dx0_refclk_sel = "R4CB" generate
		Dx0_refclk <= REFCLK_R4CB; 
		
-- Top left tile.
	elsif Dx0_refclk_sel = "L1NT" generate
		Dx0_refclk <= REFCLK_L1NT; 
	elsif Dx0_refclk_sel = "L1NB" generate
		Dx0_refclk <= REFCLK_L1NB; 
	elsif Dx0_refclk_sel = "L1MT" generate
		Dx0_refclk <= REFCLK_L1MT; 
	elsif Dx0_refclk_sel = "L1MB" generate
		Dx0_refclk <= REFCLK_L1MB; 
	elsif Dx0_refclk_sel = "L1LT" generate
		Dx0_refclk <= REFCLK_L1LT; 
	elsif Dx0_refclk_sel = "L1LB" generate
		Dx0_refclk <= REFCLK_L1LB; 
	elsif Dx0_refclk_sel = "L1KT" generate
		Dx0_refclk <= REFCLK_L1KT; 
	elsif Dx0_refclk_sel = "L1KB" generate
		Dx0_refclk <= REFCLK_L1KB; 
		
-- Bottom left tile.
	elsif Dx0_refclk_sel = "L1FT" generate
		Dx0_refclk <= REFCLK_L1FT; 
	elsif Dx0_refclk_sel = "L1FB" generate
		Dx0_refclk <= REFCLK_L1FB; 
	elsif Dx0_refclk_sel = "L1ET" generate
		Dx0_refclk <= REFCLK_L1ET; 
	elsif Dx0_refclk_sel = "L1EB" generate
		Dx0_refclk <= REFCLK_L1EB; 
	elsif Dx0_refclk_sel = "L1DT" generate
		Dx0_refclk <= REFCLK_L1DT; 
	elsif Dx0_refclk_sel = "L1DB" generate
		Dx0_refclk <= REFCLK_L1DB; 
	elsif Dx0_refclk_sel = "L1CT" generate
		Dx0_refclk <= REFCLK_L1CT; 
	elsif Dx0_refclk_sel = "L1CB" generate
		Dx0_refclk <= REFCLK_L1CB; 		
		
end generate Gen_Dx0_refclk;	

--##############################################################
--## Dx1_refclk_select  ########################################
--##############################################################

Gen_Dx1_refclk:
-- Top right tile.
	if Dx1_refclk_sel = "R4NT" generate
		Dx1_refclk <= REFCLK_R4NT; 
	elsif Dx1_refclk_sel = "R4NB" generate
		Dx1_refclk <= REFCLK_R4NB; 
	elsif Dx1_refclk_sel = "R4MT" generate
		Dx1_refclk <= REFCLK_R4MT; 
	elsif Dx1_refclk_sel = "R4MB" generate
		Dx1_refclk <= REFCLK_R4MB; 
	elsif Dx1_refclk_sel = "R4LT" generate
		Dx1_refclk <= REFCLK_R4LT; 
	elsif Dx1_refclk_sel = "R4LB" generate
		Dx1_refclk <= REFCLK_R4LB; 
	elsif Dx1_refclk_sel = "R4KT" generate
		Dx1_refclk <= REFCLK_R4KT; 
	elsif Dx1_refclk_sel = "R4KB" generate
		Dx1_refclk <= REFCLK_R4KB; 

-- Bottom right tile.
	elsif Dx1_refclk_sel = "R4FT" generate
		Dx1_refclk <= REFCLK_R4FT; 
	elsif Dx1_refclk_sel = "R4FB" generate
		Dx1_refclk <= REFCLK_R4FB; 
	elsif Dx1_refclk_sel = "R4ET" generate
		Dx1_refclk <= REFCLK_R4ET; 
	elsif Dx1_refclk_sel = "R4EB" generate
		Dx1_refclk <= REFCLK_R4EB; 
	elsif Dx1_refclk_sel = "R4DT" generate
		Dx1_refclk <= REFCLK_R4DT; 
	elsif Dx1_refclk_sel = "R4DB" generate
		Dx1_refclk <= REFCLK_R4DB; 
	elsif Dx1_refclk_sel = "R4CT" generate
		Dx1_refclk <= REFCLK_R4CT; 
	elsif Dx1_refclk_sel = "R4CB" generate
		Dx1_refclk <= REFCLK_R4CB; 
		
-- Top left tile.
	elsif Dx1_refclk_sel = "L1NT" generate
		Dx1_refclk <= REFCLK_L1NT; 
	elsif Dx1_refclk_sel = "L1NB" generate
		Dx1_refclk <= REFCLK_L1NB; 
	elsif Dx1_refclk_sel = "L1MT" generate
		Dx1_refclk <= REFCLK_L1MT; 
	elsif Dx1_refclk_sel = "L1MB" generate
		Dx1_refclk <= REFCLK_L1MB; 
	elsif Dx1_refclk_sel = "L1LT" generate
		Dx1_refclk <= REFCLK_L1LT; 
	elsif Dx1_refclk_sel = "L1LB" generate
		Dx1_refclk <= REFCLK_L1LB; 
	elsif Dx1_refclk_sel = "L1KT" generate
		Dx1_refclk <= REFCLK_L1KT; 
	elsif Dx1_refclk_sel = "L1KB" generate
		Dx1_refclk <= REFCLK_L1KB; 
		
-- Bottom left tile.
	elsif Dx1_refclk_sel = "L1FT" generate
		Dx1_refclk <= REFCLK_L1FT; 
	elsif Dx1_refclk_sel = "L1FB" generate
		Dx1_refclk <= REFCLK_L1FB; 
	elsif Dx1_refclk_sel = "L1ET" generate
		Dx1_refclk <= REFCLK_L1ET; 
	elsif Dx1_refclk_sel = "L1EB" generate
		Dx1_refclk <= REFCLK_L1EB; 
	elsif Dx1_refclk_sel = "L1DT" generate
		Dx1_refclk <= REFCLK_L1DT; 
	elsif Dx1_refclk_sel = "L1DB" generate
		Dx1_refclk <= REFCLK_L1DB; 
	elsif Dx1_refclk_sel = "L1CT" generate
		Dx1_refclk <= REFCLK_L1CT; 
	elsif Dx1_refclk_sel = "L1CB" generate
		Dx1_refclk <= REFCLK_L1CB; 		
		
end generate Gen_Dx1_refclk;	

--##############################################################
--## Dx2_refclk_select  ########################################
--##############################################################

Gen_Dx2_refclk:
-- Top right tile.
	if Dx2_refclk_sel = "R4NT" generate
		Dx2_refclk <= REFCLK_R4NT; 
	elsif Dx2_refclk_sel = "R4NB" generate
		Dx2_refclk <= REFCLK_R4NB; 
	elsif Dx2_refclk_sel = "R4MT" generate
		Dx2_refclk <= REFCLK_R4MT; 
	elsif Dx2_refclk_sel = "R4MB" generate
		Dx2_refclk <= REFCLK_R4MB; 
	elsif Dx2_refclk_sel = "R4LT" generate
		Dx2_refclk <= REFCLK_R4LT; 
	elsif Dx2_refclk_sel = "R4LB" generate
		Dx2_refclk <= REFCLK_R4LB; 
	elsif Dx2_refclk_sel = "R4KT" generate
		Dx2_refclk <= REFCLK_R4KT; 
	elsif Dx2_refclk_sel = "R4KB" generate
		Dx2_refclk <= REFCLK_R4KB; 

-- Bottom right tile.
	elsif Dx2_refclk_sel = "R4FT" generate
		Dx2_refclk <= REFCLK_R4FT; 
	elsif Dx2_refclk_sel = "R4FB" generate
		Dx2_refclk <= REFCLK_R4FB; 
	elsif Dx2_refclk_sel = "R4ET" generate
		Dx2_refclk <= REFCLK_R4ET; 
	elsif Dx2_refclk_sel = "R4EB" generate
		Dx2_refclk <= REFCLK_R4EB; 
	elsif Dx2_refclk_sel = "R4DT" generate
		Dx2_refclk <= REFCLK_R4DT; 
	elsif Dx2_refclk_sel = "R4DB" generate
		Dx2_refclk <= REFCLK_R4DB; 
	elsif Dx2_refclk_sel = "R4CT" generate
		Dx2_refclk <= REFCLK_R4CT; 
	elsif Dx2_refclk_sel = "R4CB" generate
		Dx2_refclk <= REFCLK_R4CB; 
		
-- Top left tile.
	elsif Dx2_refclk_sel = "L1NT" generate
		Dx2_refclk <= REFCLK_L1NT; 
	elsif Dx2_refclk_sel = "L1NB" generate
		Dx2_refclk <= REFCLK_L1NB; 
	elsif Dx2_refclk_sel = "L1MT" generate
		Dx2_refclk <= REFCLK_L1MT; 
	elsif Dx2_refclk_sel = "L1MB" generate
		Dx2_refclk <= REFCLK_L1MB; 
	elsif Dx2_refclk_sel = "L1LT" generate
		Dx2_refclk <= REFCLK_L1LT; 
	elsif Dx2_refclk_sel = "L1LB" generate
		Dx2_refclk <= REFCLK_L1LB; 
	elsif Dx2_refclk_sel = "L1KT" generate
		Dx2_refclk <= REFCLK_L1KT; 
	elsif Dx2_refclk_sel = "L1KB" generate
		Dx2_refclk <= REFCLK_L1KB; 
		
-- Bottom left tile.
	elsif Dx2_refclk_sel = "L1FT" generate
		Dx2_refclk <= REFCLK_L1FT; 
	elsif Dx2_refclk_sel = "L1FB" generate
		Dx2_refclk <= REFCLK_L1FB; 
	elsif Dx2_refclk_sel = "L1ET" generate
		Dx2_refclk <= REFCLK_L1ET; 
	elsif Dx2_refclk_sel = "L1EB" generate
		Dx2_refclk <= REFCLK_L1EB; 
	elsif Dx2_refclk_sel = "L1DT" generate
		Dx2_refclk <= REFCLK_L1DT; 
	elsif Dx2_refclk_sel = "L1DB" generate
		Dx2_refclk <= REFCLK_L1DB; 
	elsif Dx2_refclk_sel = "L1CT" generate
		Dx2_refclk <= REFCLK_L1CT; 
	elsif Dx2_refclk_sel = "L1CB" generate
		Dx2_refclk <= REFCLK_L1CB; 		
		
end generate Gen_Dx2_refclk;	

--##############################################################
--## Dx3_refclk_select  ########################################
--##############################################################

Gen_Dx3_refclk:
-- Top right tile.
	if Dx3_refclk_sel = "R4NT" generate
		Dx3_refclk <= REFCLK_R4NT; 
	elsif Dx3_refclk_sel = "R4NB" generate
		Dx3_refclk <= REFCLK_R4NB; 
	elsif Dx3_refclk_sel = "R4MT" generate
		Dx3_refclk <= REFCLK_R4MT; 
	elsif Dx3_refclk_sel = "R4MB" generate
		Dx3_refclk <= REFCLK_R4MB; 
	elsif Dx3_refclk_sel = "R4LT" generate
		Dx3_refclk <= REFCLK_R4LT; 
	elsif Dx3_refclk_sel = "R4LB" generate
		Dx3_refclk <= REFCLK_R4LB; 
	elsif Dx3_refclk_sel = "R4KT" generate
		Dx3_refclk <= REFCLK_R4KT; 
	elsif Dx3_refclk_sel = "R4KB" generate
		Dx3_refclk <= REFCLK_R4KB; 

-- Bottom right tile.
	elsif Dx3_refclk_sel = "R4FT" generate
		Dx3_refclk <= REFCLK_R4FT; 
	elsif Dx3_refclk_sel = "R4FB" generate
		Dx3_refclk <= REFCLK_R4FB; 
	elsif Dx3_refclk_sel = "R4ET" generate
		Dx3_refclk <= REFCLK_R4ET; 
	elsif Dx3_refclk_sel = "R4EB" generate
		Dx3_refclk <= REFCLK_R4EB; 
	elsif Dx3_refclk_sel = "R4DT" generate
		Dx3_refclk <= REFCLK_R4DT; 
	elsif Dx3_refclk_sel = "R4DB" generate
		Dx3_refclk <= REFCLK_R4DB; 
	elsif Dx3_refclk_sel = "R4CT" generate
		Dx3_refclk <= REFCLK_R4CT; 
	elsif Dx3_refclk_sel = "R4CB" generate
		Dx3_refclk <= REFCLK_R4CB; 
		
-- Top left tile.
	elsif Dx3_refclk_sel = "L1NT" generate
		Dx3_refclk <= REFCLK_L1NT; 
	elsif Dx3_refclk_sel = "L1NB" generate
		Dx3_refclk <= REFCLK_L1NB; 
	elsif Dx3_refclk_sel = "L1MT" generate
		Dx3_refclk <= REFCLK_L1MT; 
	elsif Dx3_refclk_sel = "L1MB" generate
		Dx3_refclk <= REFCLK_L1MB; 
	elsif Dx3_refclk_sel = "L1LT" generate
		Dx3_refclk <= REFCLK_L1LT; 
	elsif Dx3_refclk_sel = "L1LB" generate
		Dx3_refclk <= REFCLK_L1LB; 
	elsif Dx3_refclk_sel = "L1KT" generate
		Dx3_refclk <= REFCLK_L1KT; 
	elsif Dx3_refclk_sel = "L1KB" generate
		Dx3_refclk <= REFCLK_L1KB; 
		
-- Bottom left tile.
	elsif Dx3_refclk_sel = "L1FT" generate
		Dx3_refclk <= REFCLK_L1FT; 
	elsif Dx3_refclk_sel = "L1FB" generate
		Dx3_refclk <= REFCLK_L1FB; 
	elsif Dx3_refclk_sel = "L1ET" generate
		Dx3_refclk <= REFCLK_L1ET; 
	elsif Dx3_refclk_sel = "L1EB" generate
		Dx3_refclk <= REFCLK_L1EB; 
	elsif Dx3_refclk_sel = "L1DT" generate
		Dx3_refclk <= REFCLK_L1DT; 
	elsif Dx3_refclk_sel = "L1DB" generate
		Dx3_refclk <= REFCLK_L1DB; 
	elsif Dx3_refclk_sel = "L1CT" generate
		Dx3_refclk <= REFCLK_L1CT; 
	elsif Dx3_refclk_sel = "L1CB" generate
		Dx3_refclk <= REFCLK_L1CB; 		
		
end generate Gen_Dx3_refclk;

--##############################################################
--## Dx4_refclk_select  ########################################
--##############################################################

Gen_Dx4_refclk:
-- Top right tile.
	if Dx4_refclk_sel = "R4NT" generate
		Dx4_refclk <= REFCLK_R4NT; 
	elsif Dx4_refclk_sel = "R4NB" generate
		Dx4_refclk <= REFCLK_R4NB; 
	elsif Dx4_refclk_sel = "R4MT" generate
		Dx4_refclk <= REFCLK_R4MT; 
	elsif Dx4_refclk_sel = "R4MB" generate
		Dx4_refclk <= REFCLK_R4MB; 
	elsif Dx4_refclk_sel = "R4LT" generate
		Dx4_refclk <= REFCLK_R4LT; 
	elsif Dx4_refclk_sel = "R4LB" generate
		Dx4_refclk <= REFCLK_R4LB; 
	elsif Dx4_refclk_sel = "R4KT" generate
		Dx4_refclk <= REFCLK_R4KT; 
	elsif Dx4_refclk_sel = "R4KB" generate
		Dx4_refclk <= REFCLK_R4KB; 

-- Bottom right tile.
	elsif Dx4_refclk_sel = "R4FT" generate
		Dx4_refclk <= REFCLK_R4FT; 
	elsif Dx4_refclk_sel = "R4FB" generate
		Dx4_refclk <= REFCLK_R4FB; 
	elsif Dx4_refclk_sel = "R4ET" generate
		Dx4_refclk <= REFCLK_R4ET; 
	elsif Dx4_refclk_sel = "R4EB" generate
		Dx4_refclk <= REFCLK_R4EB; 
	elsif Dx4_refclk_sel = "R4DT" generate
		Dx4_refclk <= REFCLK_R4DT; 
	elsif Dx4_refclk_sel = "R4DB" generate
		Dx4_refclk <= REFCLK_R4DB; 
	elsif Dx4_refclk_sel = "R4CT" generate
		Dx4_refclk <= REFCLK_R4CT; 
	elsif Dx4_refclk_sel = "R4CB" generate
		Dx4_refclk <= REFCLK_R4CB; 
		
-- Top left tile.
	elsif Dx4_refclk_sel = "L1NT" generate
		Dx4_refclk <= REFCLK_L1NT; 
	elsif Dx4_refclk_sel = "L1NB" generate
		Dx4_refclk <= REFCLK_L1NB; 
	elsif Dx4_refclk_sel = "L1MT" generate
		Dx4_refclk <= REFCLK_L1MT; 
	elsif Dx4_refclk_sel = "L1MB" generate
		Dx4_refclk <= REFCLK_L1MB; 
	elsif Dx4_refclk_sel = "L1LT" generate
		Dx4_refclk <= REFCLK_L1LT; 
	elsif Dx4_refclk_sel = "L1LB" generate
		Dx4_refclk <= REFCLK_L1LB; 
	elsif Dx4_refclk_sel = "L1KT" generate
		Dx4_refclk <= REFCLK_L1KT; 
	elsif Dx4_refclk_sel = "L1KB" generate
		Dx4_refclk <= REFCLK_L1KB; 
		
-- Bottom left tile.
	elsif Dx4_refclk_sel = "L1FT" generate
		Dx4_refclk <= REFCLK_L1FT; 
	elsif Dx4_refclk_sel = "L1FB" generate
		Dx4_refclk <= REFCLK_L1FB; 
	elsif Dx4_refclk_sel = "L1ET" generate
		Dx4_refclk <= REFCLK_L1ET; 
	elsif Dx4_refclk_sel = "L1EB" generate
		Dx4_refclk <= REFCLK_L1EB; 
	elsif Dx4_refclk_sel = "L1DT" generate
		Dx4_refclk <= REFCLK_L1DT; 
	elsif Dx4_refclk_sel = "L1DB" generate
		Dx4_refclk <= REFCLK_L1DB; 
	elsif Dx4_refclk_sel = "L1CT" generate
		Dx4_refclk <= REFCLK_L1CT; 
	elsif Dx4_refclk_sel = "L1CB" generate
		Dx4_refclk <= REFCLK_L1CB; 		
		
end generate Gen_Dx4_refclk;	

--##############################################################
--## Dx5_refclk_select  ########################################
--##############################################################

Gen_Dx5_refclk:
-- Top right tile.
	if Dx5_refclk_sel = "R4NT" generate
		Dx5_refclk <= REFCLK_R4NT; 
	elsif Dx5_refclk_sel = "R4NB" generate
		Dx5_refclk <= REFCLK_R4NB; 
	elsif Dx5_refclk_sel = "R4MT" generate
		Dx5_refclk <= REFCLK_R4MT; 
	elsif Dx5_refclk_sel = "R4MB" generate
		Dx5_refclk <= REFCLK_R4MB; 
	elsif Dx5_refclk_sel = "R4LT" generate
		Dx5_refclk <= REFCLK_R4LT; 
	elsif Dx5_refclk_sel = "R4LB" generate
		Dx5_refclk <= REFCLK_R4LB; 
	elsif Dx5_refclk_sel = "R4KT" generate
		Dx5_refclk <= REFCLK_R4KT; 
	elsif Dx5_refclk_sel = "R4KB" generate
		Dx5_refclk <= REFCLK_R4KB; 

-- Bottom right tile.
	elsif Dx5_refclk_sel = "R4FT" generate
		Dx5_refclk <= REFCLK_R4FT; 
	elsif Dx5_refclk_sel = "R4FB" generate
		Dx5_refclk <= REFCLK_R4FB; 
	elsif Dx5_refclk_sel = "R4ET" generate
		Dx5_refclk <= REFCLK_R4ET; 
	elsif Dx5_refclk_sel = "R4EB" generate
		Dx5_refclk <= REFCLK_R4EB; 
	elsif Dx5_refclk_sel = "R4DT" generate
		Dx5_refclk <= REFCLK_R4DT; 
	elsif Dx5_refclk_sel = "R4DB" generate
		Dx5_refclk <= REFCLK_R4DB; 
	elsif Dx5_refclk_sel = "R4CT" generate
		Dx5_refclk <= REFCLK_R4CT; 
	elsif Dx5_refclk_sel = "R4CB" generate
		Dx5_refclk <= REFCLK_R4CB; 
		
-- Top left tile.
	elsif Dx5_refclk_sel = "L1NT" generate
		Dx5_refclk <= REFCLK_L1NT; 
	elsif Dx5_refclk_sel = "L1NB" generate
		Dx5_refclk <= REFCLK_L1NB; 
	elsif Dx5_refclk_sel = "L1MT" generate
		Dx5_refclk <= REFCLK_L1MT; 
	elsif Dx5_refclk_sel = "L1MB" generate
		Dx5_refclk <= REFCLK_L1MB; 
	elsif Dx5_refclk_sel = "L1LT" generate
		Dx5_refclk <= REFCLK_L1LT; 
	elsif Dx5_refclk_sel = "L1LB" generate
		Dx5_refclk <= REFCLK_L1LB; 
	elsif Dx5_refclk_sel = "L1KT" generate
		Dx5_refclk <= REFCLK_L1KT; 
	elsif Dx5_refclk_sel = "L1KB" generate
		Dx5_refclk <= REFCLK_L1KB; 
		
-- Bottom left tile.
	elsif Dx5_refclk_sel = "L1FT" generate
		Dx5_refclk <= REFCLK_L1FT; 
	elsif Dx5_refclk_sel = "L1FB" generate
		Dx5_refclk <= REFCLK_L1FB; 
	elsif Dx5_refclk_sel = "L1ET" generate
		Dx5_refclk <= REFCLK_L1ET; 
	elsif Dx5_refclk_sel = "L1EB" generate
		Dx5_refclk <= REFCLK_L1EB; 
	elsif Dx5_refclk_sel = "L1DT" generate
		Dx5_refclk <= REFCLK_L1DT; 
	elsif Dx5_refclk_sel = "L1DB" generate
		Dx5_refclk <= REFCLK_L1DB; 
	elsif Dx5_refclk_sel = "L1CT" generate
		Dx5_refclk <= REFCLK_L1CT; 
	elsif Dx5_refclk_sel = "L1CB" generate
		Dx5_refclk <= REFCLK_L1CB; 		
		
end generate Gen_Dx5_refclk;
--##############################################################
--## Dx6_refclk_select  ########################################
--##############################################################

Gen_Dx6_refclk:
-- Top right tile.
	if Dx6_refclk_sel = "R4NT" generate
		Dx6_refclk <= REFCLK_R4NT; 
	elsif Dx6_refclk_sel = "R4NB" generate
		Dx6_refclk <= REFCLK_R4NB; 
	elsif Dx6_refclk_sel = "R4MT" generate
		Dx6_refclk <= REFCLK_R4MT; 
	elsif Dx6_refclk_sel = "R4MB" generate
		Dx6_refclk <= REFCLK_R4MB; 
	elsif Dx6_refclk_sel = "R4LT" generate
		Dx6_refclk <= REFCLK_R4LT; 
	elsif Dx6_refclk_sel = "R4LB" generate
		Dx6_refclk <= REFCLK_R4LB; 
	elsif Dx6_refclk_sel = "R4KT" generate
		Dx6_refclk <= REFCLK_R4KT; 
	elsif Dx6_refclk_sel = "R4KB" generate
		Dx6_refclk <= REFCLK_R4KB; 

-- Bottom right tile.
	elsif Dx6_refclk_sel = "R4FT" generate
		Dx6_refclk <= REFCLK_R4FT; 
	elsif Dx6_refclk_sel = "R4FB" generate
		Dx6_refclk <= REFCLK_R4FB; 
	elsif Dx6_refclk_sel = "R4ET" generate
		Dx6_refclk <= REFCLK_R4ET; 
	elsif Dx6_refclk_sel = "R4EB" generate
		Dx6_refclk <= REFCLK_R4EB; 
	elsif Dx6_refclk_sel = "R4DT" generate
		Dx6_refclk <= REFCLK_R4DT; 
	elsif Dx6_refclk_sel = "R4DB" generate
		Dx6_refclk <= REFCLK_R4DB; 
	elsif Dx6_refclk_sel = "R4CT" generate
		Dx6_refclk <= REFCLK_R4CT; 
	elsif Dx6_refclk_sel = "R4CB" generate
		Dx6_refclk <= REFCLK_R4CB; 
		
-- Top left tile.
	elsif Dx6_refclk_sel = "L1NT" generate
		Dx6_refclk <= REFCLK_L1NT; 
	elsif Dx6_refclk_sel = "L1NB" generate
		Dx6_refclk <= REFCLK_L1NB; 
	elsif Dx6_refclk_sel = "L1MT" generate
		Dx6_refclk <= REFCLK_L1MT; 
	elsif Dx6_refclk_sel = "L1MB" generate
		Dx6_refclk <= REFCLK_L1MB; 
	elsif Dx6_refclk_sel = "L1LT" generate
		Dx6_refclk <= REFCLK_L1LT; 
	elsif Dx6_refclk_sel = "L1LB" generate
		Dx6_refclk <= REFCLK_L1LB; 
	elsif Dx6_refclk_sel = "L1KT" generate
		Dx6_refclk <= REFCLK_L1KT; 
	elsif Dx6_refclk_sel = "L1KB" generate
		Dx6_refclk <= REFCLK_L1KB; 
		
-- Bottom left tile.
	elsif Dx6_refclk_sel = "L1FT" generate
		Dx6_refclk <= REFCLK_L1FT; 
	elsif Dx6_refclk_sel = "L1FB" generate
		Dx6_refclk <= REFCLK_L1FB; 
	elsif Dx6_refclk_sel = "L1ET" generate
		Dx6_refclk <= REFCLK_L1ET; 
	elsif Dx6_refclk_sel = "L1EB" generate
		Dx6_refclk <= REFCLK_L1EB; 
	elsif Dx6_refclk_sel = "L1DT" generate
		Dx6_refclk <= REFCLK_L1DT; 
	elsif Dx6_refclk_sel = "L1DB" generate
		Dx6_refclk <= REFCLK_L1DB; 
	elsif Dx6_refclk_sel = "L1CT" generate
		Dx6_refclk <= REFCLK_L1CT; 
	elsif Dx6_refclk_sel = "L1CB" generate
		Dx6_refclk <= REFCLK_L1CB; 		
		
end generate Gen_Dx6_refclk;

--##############################################################
--## Dx7_refclk_select  ########################################
--##############################################################

Gen_Dx7_refclk:
-- Top right tile.
	if Dx7_refclk_sel = "R4NT" generate
		Dx7_refclk <= REFCLK_R4NT; 
	elsif Dx7_refclk_sel = "R4NB" generate
		Dx7_refclk <= REFCLK_R4NB; 
	elsif Dx7_refclk_sel = "R4MT" generate
		Dx7_refclk <= REFCLK_R4MT; 
	elsif Dx7_refclk_sel = "R4MB" generate
		Dx7_refclk <= REFCLK_R4MB; 
	elsif Dx7_refclk_sel = "R4LT" generate
		Dx7_refclk <= REFCLK_R4LT; 
	elsif Dx7_refclk_sel = "R4LB" generate
		Dx7_refclk <= REFCLK_R4LB; 
	elsif Dx7_refclk_sel = "R4KT" generate
		Dx7_refclk <= REFCLK_R4KT; 
	elsif Dx7_refclk_sel = "R4KB" generate
		Dx7_refclk <= REFCLK_R4KB; 

-- Bottom right tile.
	elsif Dx7_refclk_sel = "R4FT" generate
		Dx7_refclk <= REFCLK_R4FT; 
	elsif Dx7_refclk_sel = "R4FB" generate
		Dx7_refclk <= REFCLK_R4FB; 
	elsif Dx7_refclk_sel = "R4ET" generate
		Dx7_refclk <= REFCLK_R4ET; 
	elsif Dx7_refclk_sel = "R4EB" generate
		Dx7_refclk <= REFCLK_R4EB; 
	elsif Dx7_refclk_sel = "R4DT" generate
		Dx7_refclk <= REFCLK_R4DT; 
	elsif Dx7_refclk_sel = "R4CB" generate
		Dx7_refclk <= REFCLK_R4CB; 
	elsif Dx7_refclk_sel = "R4CT" generate
		Dx7_refclk <= REFCLK_R4CT; 
	elsif Dx7_refclk_sel = "R4CB" generate
		Dx7_refclk <= REFCLK_R4CB; 
		
-- Top left tile.
	elsif Dx7_refclk_sel = "L1NT" generate
		Dx7_refclk <= REFCLK_L1NT; 
	elsif Dx7_refclk_sel = "L1NB" generate
		Dx7_refclk <= REFCLK_L1NB; 
	elsif Dx7_refclk_sel = "L1MT" generate
		Dx7_refclk <= REFCLK_L1MT; 
	elsif Dx7_refclk_sel = "L1MB" generate
		Dx7_refclk <= REFCLK_L1MB; 
	elsif Dx7_refclk_sel = "L1LT" generate
		Dx7_refclk <= REFCLK_L1LT; 
	elsif Dx7_refclk_sel = "L1LB" generate
		Dx7_refclk <= REFCLK_L1LB; 
	elsif Dx7_refclk_sel = "L1KT" generate
		Dx7_refclk <= REFCLK_L1KT; 
	elsif Dx7_refclk_sel = "L1KB" generate
		Dx7_refclk <= REFCLK_L1KB; 
		
-- Bottom left tile.
	elsif Dx7_refclk_sel = "L1FT" generate
		Dx7_refclk <= REFCLK_L1FT; 
	elsif Dx7_refclk_sel = "L1FB" generate
		Dx7_refclk <= REFCLK_L1FB; 
	elsif Dx7_refclk_sel = "L1ET" generate
		Dx7_refclk <= REFCLK_L1ET; 
	elsif Dx7_refclk_sel = "L1EB" generate
		Dx7_refclk <= REFCLK_L1EB; 
	elsif Dx7_refclk_sel = "L1DT" generate
		Dx7_refclk <= REFCLK_L1DT; 
	elsif Dx7_refclk_sel = "L1DB" generate
		Dx7_refclk <= REFCLK_L1DB; 
	elsif Dx7_refclk_sel = "L1CT" generate
		Dx7_refclk <= REFCLK_L1CT; 
	elsif Dx7_refclk_sel = "L1CB" generate
		Dx7_refclk <= REFCLK_L1CB; 		
		
end generate Gen_Dx7_refclk;

--##############################################################
--## Tx0_refclk_select  ########################################
--##############################################################

Gen_Tx0_refclk:
-- Top right tile.
	if Tx0_refclk_sel = "R4NT" generate
		Tx0_refclk <= REFCLK_R4NT; 
	elsif Tx0_refclk_sel = "R4NB" generate
		Tx0_refclk <= REFCLK_R4NB; 
	elsif Tx0_refclk_sel = "R4MT" generate
		Tx0_refclk <= REFCLK_R4MT; 
	elsif Tx0_refclk_sel = "R4MB" generate
		Tx0_refclk <= REFCLK_R4MB; 
	elsif Tx0_refclk_sel = "R4LT" generate
		Tx0_refclk <= REFCLK_R4LT; 
	elsif Tx0_refclk_sel = "R4LB" generate
		Tx0_refclk <= REFCLK_R4LB; 
	elsif Tx0_refclk_sel = "R4KT" generate
		Tx0_refclk <= REFCLK_R4KT; 
	elsif Tx0_refclk_sel = "R4KB" generate
		Tx0_refclk <= REFCLK_R4KB; 

-- Bottom right tile.
	elsif Tx0_refclk_sel = "R4FT" generate
		Tx0_refclk <= REFCLK_R4FT; 
	elsif Tx0_refclk_sel = "R4FB" generate
		Tx0_refclk <= REFCLK_R4FB; 
	elsif Tx0_refclk_sel = "R4ET" generate
		Tx0_refclk <= REFCLK_R4ET; 
	elsif Tx0_refclk_sel = "R4EB" generate
		Tx0_refclk <= REFCLK_R4EB; 
	elsif Tx0_refclk_sel = "R4DT" generate
		Tx0_refclk <= REFCLK_R4DT; 
	elsif Tx0_refclk_sel = "R4DB" generate
		Tx0_refclk <= REFCLK_R4DB; 
	elsif Tx0_refclk_sel = "R4CT" generate
		Tx0_refclk <= REFCLK_R4CT; 
	elsif Tx0_refclk_sel = "R4CB" generate
		Tx0_refclk <= REFCLK_R4CB; 
		
-- Top left tile.
	elsif Tx0_refclk_sel = "L1NT" generate
		Tx0_refclk <= REFCLK_L1NT; 
	elsif Tx0_refclk_sel = "L1NB" generate
		Tx0_refclk <= REFCLK_L1NB; 
	elsif Tx0_refclk_sel = "L1MT" generate
		Tx0_refclk <= REFCLK_L1MT; 
	elsif Tx0_refclk_sel = "L1MB" generate
		Tx0_refclk <= REFCLK_L1MB; 
	elsif Tx0_refclk_sel = "L1LT" generate
		Tx0_refclk <= REFCLK_L1LT; 
	elsif Tx0_refclk_sel = "L1LB" generate
		Tx0_refclk <= REFCLK_L1LB; 
	elsif Tx0_refclk_sel = "L1KT" generate
		Tx0_refclk <= REFCLK_L1KT; 
	elsif Tx0_refclk_sel = "L1KB" generate
		Tx0_refclk <= REFCLK_L1KB; 
		
-- Bottom left tile.
	elsif Tx0_refclk_sel = "L1FT" generate
		Tx0_refclk <= REFCLK_L1FT; 
	elsif Tx0_refclk_sel = "L1FB" generate
		Tx0_refclk <= REFCLK_L1FB; 
	elsif Tx0_refclk_sel = "L1ET" generate
		Tx0_refclk <= REFCLK_L1ET; 
	elsif Tx0_refclk_sel = "L1EB" generate
		Tx0_refclk <= REFCLK_L1EB; 
	elsif Tx0_refclk_sel = "L1DT" generate
		Tx0_refclk <= REFCLK_L1DT; 
	elsif Tx0_refclk_sel = "L1DB" generate
		Tx0_refclk <= REFCLK_L1DB; 
	elsif Tx0_refclk_sel = "L1CT" generate
		Tx0_refclk <= REFCLK_L1CT; 
	elsif Tx0_refclk_sel = "L1CB" generate
		Tx0_refclk <= REFCLK_L1CB; 		
		
end generate Gen_Tx0_refclk;	

--##############################################################
--## Tx1_refclk_select  ########################################
--##############################################################

Gen_Tx1_refclk:
-- Top right tile.
	if Tx1_refclk_sel = "R4NT" generate
		Tx1_refclk <= REFCLK_R4NT; 
	elsif Tx1_refclk_sel = "R4NB" generate
		Tx1_refclk <= REFCLK_R4NB; 
	elsif Tx1_refclk_sel = "R4MT" generate
		Tx1_refclk <= REFCLK_R4MT; 
	elsif Tx1_refclk_sel = "R4MB" generate
		Tx1_refclk <= REFCLK_R4MB; 
	elsif Tx1_refclk_sel = "R4LT" generate
		Tx1_refclk <= REFCLK_R4LT; 
	elsif Tx1_refclk_sel = "R4LB" generate
		Tx1_refclk <= REFCLK_R4LB; 
	elsif Tx1_refclk_sel = "R4KT" generate
		Tx1_refclk <= REFCLK_R4KT; 
	elsif Tx1_refclk_sel = "R4KB" generate
		Tx1_refclk <= REFCLK_R4KB; 

-- Bottom right tile.
	elsif Tx1_refclk_sel = "R4FT" generate
		Tx1_refclk <= REFCLK_R4FT; 
	elsif Tx1_refclk_sel = "R4FB" generate
		Tx1_refclk <= REFCLK_R4FB; 
	elsif Tx1_refclk_sel = "R4ET" generate
		Tx1_refclk <= REFCLK_R4ET; 
	elsif Tx1_refclk_sel = "R4EB" generate
		Tx1_refclk <= REFCLK_R4EB; 
	elsif Tx1_refclk_sel = "R4DT" generate
		Tx1_refclk <= REFCLK_R4DT; 
	elsif Tx1_refclk_sel = "R4DB" generate
		Tx1_refclk <= REFCLK_R4DB; 
	elsif Tx1_refclk_sel = "R4CT" generate
		Tx1_refclk <= REFCLK_R4CT; 
	elsif Tx1_refclk_sel = "R4CB" generate
		Tx1_refclk <= REFCLK_R4CB; 
		
-- Top left tile.
	elsif Tx1_refclk_sel = "L1NT" generate
		Tx1_refclk <= REFCLK_L1NT; 
	elsif Tx1_refclk_sel = "L1NB" generate
		Tx1_refclk <= REFCLK_L1NB; 
	elsif Tx1_refclk_sel = "L1MT" generate
		Tx1_refclk <= REFCLK_L1MT; 
	elsif Tx1_refclk_sel = "L1MB" generate
		Tx1_refclk <= REFCLK_L1MB; 
	elsif Tx1_refclk_sel = "L1LT" generate
		Tx1_refclk <= REFCLK_L1LT; 
	elsif Tx1_refclk_sel = "L1LB" generate
		Tx1_refclk <= REFCLK_L1LB; 
	elsif Tx1_refclk_sel = "L1KT" generate
		Tx1_refclk <= REFCLK_L1KT; 
	elsif Tx1_refclk_sel = "L1KB" generate
		Tx1_refclk <= REFCLK_L1KB; 
		
-- Bottom left tile.
	elsif Tx1_refclk_sel = "L1FT" generate
		Tx1_refclk <= REFCLK_L1FT; 
	elsif Tx1_refclk_sel = "L1FB" generate
		Tx1_refclk <= REFCLK_L1FB; 
	elsif Tx1_refclk_sel = "L1ET" generate
		Tx1_refclk <= REFCLK_L1ET; 
	elsif Tx1_refclk_sel = "L1EB" generate
		Tx1_refclk <= REFCLK_L1EB; 
	elsif Tx1_refclk_sel = "L1DT" generate
		Tx1_refclk <= REFCLK_L1DT; 
	elsif Tx1_refclk_sel = "L1DB" generate
		Tx1_refclk <= REFCLK_L1DB; 
	elsif Tx1_refclk_sel = "L1CT" generate
		Tx1_refclk <= REFCLK_L1CT; 
	elsif Tx1_refclk_sel = "L1CB" generate
		Tx1_refclk <= REFCLK_L1CB; 		
		
end generate Gen_Tx1_refclk;	

--##############################################################
--## Tx2_refclk_select  ########################################
--##############################################################

Gen_Tx2_refclk:
-- Top right tile.
	if Tx2_refclk_sel = "R4NT" generate
		Tx2_refclk <= REFCLK_R4NT; 
	elsif Tx2_refclk_sel = "R4NB" generate
		Tx2_refclk <= REFCLK_R4NB; 
	elsif Tx2_refclk_sel = "R4MT" generate
		Tx2_refclk <= REFCLK_R4MT; 
	elsif Tx2_refclk_sel = "R4MB" generate
		Tx2_refclk <= REFCLK_R4MB; 
	elsif Tx2_refclk_sel = "R4LT" generate
		Tx2_refclk <= REFCLK_R4LT; 
	elsif Tx2_refclk_sel = "R4LB" generate
		Tx2_refclk <= REFCLK_R4LB; 
	elsif Tx2_refclk_sel = "R4KT" generate
		Tx2_refclk <= REFCLK_R4KT; 
	elsif Tx2_refclk_sel = "R4KB" generate
		Tx2_refclk <= REFCLK_R4KB; 

-- Bottom right tile.
	elsif Tx2_refclk_sel = "R4FT" generate
		Tx2_refclk <= REFCLK_R4FT; 
	elsif Tx2_refclk_sel = "R4FB" generate
		Tx2_refclk <= REFCLK_R4FB; 
	elsif Tx2_refclk_sel = "R4ET" generate
		Tx2_refclk <= REFCLK_R4ET; 
	elsif Tx2_refclk_sel = "R4EB" generate
		Tx2_refclk <= REFCLK_R4EB; 
	elsif Tx2_refclk_sel = "R4DT" generate
		Tx2_refclk <= REFCLK_R4DT; 
	elsif Tx2_refclk_sel = "R4DB" generate
		Tx2_refclk <= REFCLK_R4DB; 
	elsif Tx2_refclk_sel = "R4CT" generate
		Tx2_refclk <= REFCLK_R4CT; 
	elsif Tx2_refclk_sel = "R4CB" generate
		Tx2_refclk <= REFCLK_R4CB; 
		
-- Top left tile.
	elsif Tx2_refclk_sel = "L1NT" generate
		Tx2_refclk <= REFCLK_L1NT; 
	elsif Tx2_refclk_sel = "L1NB" generate
		Tx2_refclk <= REFCLK_L1NB; 
	elsif Tx2_refclk_sel = "L1MT" generate
		Tx2_refclk <= REFCLK_L1MT; 
	elsif Tx2_refclk_sel = "L1MB" generate
		Tx2_refclk <= REFCLK_L1MB; 
	elsif Tx2_refclk_sel = "L1LT" generate
		Tx2_refclk <= REFCLK_L1LT; 
	elsif Tx2_refclk_sel = "L1LB" generate
		Tx2_refclk <= REFCLK_L1LB; 
	elsif Tx2_refclk_sel = "L1KT" generate
		Tx2_refclk <= REFCLK_L1KT; 
	elsif Tx2_refclk_sel = "L1KB" generate
		Tx2_refclk <= REFCLK_L1KB; 
		
-- Bottom left tile.
	elsif Tx2_refclk_sel = "L1FT" generate
		Tx2_refclk <= REFCLK_L1FT; 
	elsif Tx2_refclk_sel = "L1FB" generate
		Tx2_refclk <= REFCLK_L1FB; 
	elsif Tx2_refclk_sel = "L1ET" generate
		Tx2_refclk <= REFCLK_L1ET; 
	elsif Tx2_refclk_sel = "L1EB" generate
		Tx2_refclk <= REFCLK_L1EB; 
	elsif Tx2_refclk_sel = "L1DT" generate
		Tx2_refclk <= REFCLK_L1DT; 
	elsif Tx2_refclk_sel = "L1DB" generate
		Tx2_refclk <= REFCLK_L1DB; 
	elsif Tx2_refclk_sel = "L1CT" generate
		Tx2_refclk <= REFCLK_L1CT; 
	elsif Tx2_refclk_sel = "L1CB" generate
		Tx2_refclk <= REFCLK_L1CB; 		
		
end generate Gen_Tx2_refclk;	

--##############################################################
--## Tx3_refclk_select  ########################################
--##############################################################

Gen_Tx3_refclk:
-- Top right tile.
	if Tx3_refclk_sel = "R4NT" generate
		Tx3_refclk <= REFCLK_R4NT; 
	elsif Tx3_refclk_sel = "R4NB" generate
		Tx3_refclk <= REFCLK_R4NB; 
	elsif Tx3_refclk_sel = "R4MT" generate
		Tx3_refclk <= REFCLK_R4MT; 
	elsif Tx3_refclk_sel = "R4MB" generate
		Tx3_refclk <= REFCLK_R4MB; 
	elsif Tx3_refclk_sel = "R4LT" generate
		Tx3_refclk <= REFCLK_R4LT; 
	elsif Tx3_refclk_sel = "R4LB" generate
		Tx3_refclk <= REFCLK_R4LB; 
	elsif Tx3_refclk_sel = "R4KT" generate
		Tx3_refclk <= REFCLK_R4KT; 
	elsif Tx3_refclk_sel = "R4KB" generate
		Tx3_refclk <= REFCLK_R4KB; 

-- Bottom right tile.
	elsif Tx3_refclk_sel = "R4FT" generate
		Tx3_refclk <= REFCLK_R4FT; 
	elsif Tx3_refclk_sel = "R4FB" generate
		Tx3_refclk <= REFCLK_R4FB; 
	elsif Tx3_refclk_sel = "R4ET" generate
		Tx3_refclk <= REFCLK_R4ET; 
	elsif Tx3_refclk_sel = "R4EB" generate
		Tx3_refclk <= REFCLK_R4EB; 
	elsif Tx3_refclk_sel = "R4DT" generate
		Tx3_refclk <= REFCLK_R4DT; 
	elsif Tx3_refclk_sel = "R4DB" generate
		Tx3_refclk <= REFCLK_R4DB; 
	elsif Tx3_refclk_sel = "R4CT" generate
		Tx3_refclk <= REFCLK_R4CT; 
	elsif Tx3_refclk_sel = "R4CB" generate
		Tx3_refclk <= REFCLK_R4CB; 
		
-- Top left tile.
	elsif Tx3_refclk_sel = "L1NT" generate
		Tx3_refclk <= REFCLK_L1NT; 
	elsif Tx3_refclk_sel = "L1NB" generate
		Tx3_refclk <= REFCLK_L1NB; 
	elsif Tx3_refclk_sel = "L1MT" generate
		Tx3_refclk <= REFCLK_L1MT; 
	elsif Tx3_refclk_sel = "L1MB" generate
		Tx3_refclk <= REFCLK_L1MB; 
	elsif Tx3_refclk_sel = "L1LT" generate
		Tx3_refclk <= REFCLK_L1LT; 
	elsif Tx3_refclk_sel = "L1LB" generate
		Tx3_refclk <= REFCLK_L1LB; 
	elsif Tx3_refclk_sel = "L1KT" generate
		Tx3_refclk <= REFCLK_L1KT; 
	elsif Tx3_refclk_sel = "L1KB" generate
		Tx3_refclk <= REFCLK_L1KB; 
		
-- Bottom left tile.
	elsif Tx3_refclk_sel = "L1FT" generate
		Tx3_refclk <= REFCLK_L1FT; 
	elsif Tx3_refclk_sel = "L1FB" generate
		Tx3_refclk <= REFCLK_L1FB; 
	elsif Tx3_refclk_sel = "L1ET" generate
		Tx3_refclk <= REFCLK_L1ET; 
	elsif Tx3_refclk_sel = "L1EB" generate
		Tx3_refclk <= REFCLK_L1EB; 
	elsif Tx3_refclk_sel = "L1DT" generate
		Tx3_refclk <= REFCLK_L1DT; 
	elsif Tx3_refclk_sel = "L1DB" generate
		Tx3_refclk <= REFCLK_L1DB; 
	elsif Tx3_refclk_sel = "L1CT" generate
		Tx3_refclk <= REFCLK_L1CT; 
	elsif Tx3_refclk_sel = "L1CB" generate
		Tx3_refclk <= REFCLK_L1CB; 		
		
end generate Gen_Tx3_refclk;

--##############################################################
--## Rx0_refclk_select  ########################################
--##############################################################

Gen_Rx0_refclk:
-- Top right tile.
	if Rx0_refclk_sel = "R4NT" generate
		Rx0_refclk <= REFCLK_R4NT; 
	elsif Rx0_refclk_sel = "R4NB" generate
		Rx0_refclk <= REFCLK_R4NB; 
	elsif Rx0_refclk_sel = "R4MT" generate
		Rx0_refclk <= REFCLK_R4MT; 
	elsif Rx0_refclk_sel = "R4MB" generate
		Rx0_refclk <= REFCLK_R4MB; 
	elsif Rx0_refclk_sel = "R4LT" generate
		Rx0_refclk <= REFCLK_R4LT; 
	elsif Rx0_refclk_sel = "R4LB" generate
		Rx0_refclk <= REFCLK_R4LB; 
	elsif Rx0_refclk_sel = "R4KT" generate
		Rx0_refclk <= REFCLK_R4KT; 
	elsif Rx0_refclk_sel = "R4KB" generate
		Rx0_refclk <= REFCLK_R4KB; 

-- Bottom right tile.
	elsif Rx0_refclk_sel = "R4FT" generate
		Rx0_refclk <= REFCLK_R4FT; 
	elsif Rx0_refclk_sel = "R4FB" generate
		Rx0_refclk <= REFCLK_R4FB; 
	elsif Rx0_refclk_sel = "R4ET" generate
		Rx0_refclk <= REFCLK_R4ET; 
	elsif Rx0_refclk_sel = "R4EB" generate
		Rx0_refclk <= REFCLK_R4EB; 
	elsif Rx0_refclk_sel = "R4DT" generate
		Rx0_refclk <= REFCLK_R4DT; 
	elsif Rx0_refclk_sel = "R4DB" generate
		Rx0_refclk <= REFCLK_R4DB; 
	elsif Rx0_refclk_sel = "R4CT" generate
		Rx0_refclk <= REFCLK_R4CT; 
	elsif Rx0_refclk_sel = "R4CB" generate
		Rx0_refclk <= REFCLK_R4CB; 
		
-- Top left tile.
	elsif Rx0_refclk_sel = "L1NT" generate
		Rx0_refclk <= REFCLK_L1NT; 
	elsif Rx0_refclk_sel = "L1NB" generate
		Rx0_refclk <= REFCLK_L1NB; 
	elsif Rx0_refclk_sel = "L1MT" generate
		Rx0_refclk <= REFCLK_L1MT; 
	elsif Rx0_refclk_sel = "L1MB" generate
		Rx0_refclk <= REFCLK_L1MB; 
	elsif Rx0_refclk_sel = "L1LT" generate
		Rx0_refclk <= REFCLK_L1LT; 
	elsif Rx0_refclk_sel = "L1LB" generate
		Rx0_refclk <= REFCLK_L1LB; 
	elsif Rx0_refclk_sel = "L1KT" generate
		Rx0_refclk <= REFCLK_L1KT; 
	elsif Rx0_refclk_sel = "L1KB" generate
		Rx0_refclk <= REFCLK_L1KB; 
		
-- Bottom left tile.
	elsif Rx0_refclk_sel = "L1FT" generate
		Rx0_refclk <= REFCLK_L1FT; 
	elsif Rx0_refclk_sel = "L1FB" generate
		Rx0_refclk <= REFCLK_L1FB; 
	elsif Rx0_refclk_sel = "L1ET" generate
		Rx0_refclk <= REFCLK_L1ET; 
	elsif Rx0_refclk_sel = "L1EB" generate
		Rx0_refclk <= REFCLK_L1EB; 
	elsif Rx0_refclk_sel = "L1DT" generate
		Rx0_refclk <= REFCLK_L1DT; 
	elsif Rx0_refclk_sel = "L1DB" generate
		Rx0_refclk <= REFCLK_L1DB; 
	elsif Rx0_refclk_sel = "L1CT" generate
		Rx0_refclk <= REFCLK_L1CT; 
	elsif Rx0_refclk_sel = "L1CB" generate
		Rx0_refclk <= REFCLK_L1CB; 		
		
end generate Gen_Rx0_refclk;	

--##############################################################
--## Rx1_refclk_select  ########################################
--##############################################################

Gen_Rx1_refclk:
-- Top right tile.
	if Rx1_refclk_sel = "R4NT" generate
		Rx1_refclk <= REFCLK_R4NT; 
	elsif Rx1_refclk_sel = "R4NB" generate
		Rx1_refclk <= REFCLK_R4NB; 
	elsif Rx1_refclk_sel = "R4MT" generate
		Rx1_refclk <= REFCLK_R4MT; 
	elsif Rx1_refclk_sel = "R4MB" generate
		Rx1_refclk <= REFCLK_R4MB; 
	elsif Rx1_refclk_sel = "R4LT" generate
		Rx1_refclk <= REFCLK_R4LT; 
	elsif Rx1_refclk_sel = "R4LB" generate
		Rx1_refclk <= REFCLK_R4LB; 
	elsif Rx1_refclk_sel = "R4KT" generate
		Rx1_refclk <= REFCLK_R4KT; 
	elsif Rx1_refclk_sel = "R4KB" generate
		Rx1_refclk <= REFCLK_R4KB; 

-- Bottom right tile.
	elsif Rx1_refclk_sel = "R4FT" generate
		Rx1_refclk <= REFCLK_R4FT; 
	elsif Rx1_refclk_sel = "R4FB" generate
		Rx1_refclk <= REFCLK_R4FB; 
	elsif Rx1_refclk_sel = "R4ET" generate
		Rx1_refclk <= REFCLK_R4ET; 
	elsif Rx1_refclk_sel = "R4EB" generate
		Rx1_refclk <= REFCLK_R4EB; 
	elsif Rx1_refclk_sel = "R4DT" generate
		Rx1_refclk <= REFCLK_R4DT; 
	elsif Rx1_refclk_sel = "R4DB" generate
		Rx1_refclk <= REFCLK_R4DB; 
	elsif Rx1_refclk_sel = "R4CT" generate
		Rx1_refclk <= REFCLK_R4CT; 
	elsif Rx1_refclk_sel = "R4CB" generate
		Rx1_refclk <= REFCLK_R4CB; 
		
-- Top left tile.
	elsif Rx1_refclk_sel = "L1NT" generate
		Rx1_refclk <= REFCLK_L1NT; 
	elsif Rx1_refclk_sel = "L1NB" generate
		Rx1_refclk <= REFCLK_L1NB; 
	elsif Rx1_refclk_sel = "L1MT" generate
		Rx1_refclk <= REFCLK_L1MT; 
	elsif Rx1_refclk_sel = "L1MB" generate
		Rx1_refclk <= REFCLK_L1MB; 
	elsif Rx1_refclk_sel = "L1LT" generate
		Rx1_refclk <= REFCLK_L1LT; 
	elsif Rx1_refclk_sel = "L1LB" generate
		Rx1_refclk <= REFCLK_L1LB; 
	elsif Rx1_refclk_sel = "L1KT" generate
		Rx1_refclk <= REFCLK_L1KT; 
	elsif Rx1_refclk_sel = "L1KB" generate
		Rx1_refclk <= REFCLK_L1KB; 
		
-- Bottom left tile.
	elsif Rx1_refclk_sel = "L1FT" generate
		Rx1_refclk <= REFCLK_L1FT; 
	elsif Rx1_refclk_sel = "L1FB" generate
		Rx1_refclk <= REFCLK_L1FB; 
	elsif Rx1_refclk_sel = "L1ET" generate
		Rx1_refclk <= REFCLK_L1ET; 
	elsif Rx1_refclk_sel = "L1EB" generate
		Rx1_refclk <= REFCLK_L1EB; 
	elsif Rx1_refclk_sel = "L1DT" generate
		Rx1_refclk <= REFCLK_L1DT; 
	elsif Rx1_refclk_sel = "L1DB" generate
		Rx1_refclk <= REFCLK_L1DB; 
	elsif Rx1_refclk_sel = "L1CT" generate
		Rx1_refclk <= REFCLK_L1CT; 
	elsif Rx1_refclk_sel = "L1CB" generate
		Rx1_refclk <= REFCLK_L1CB; 		
		
end generate Gen_Rx1_refclk;	

--##############################################################
--## Rx2_refclk_select  ########################################
--##############################################################

Gen_Rx2_refclk:
-- Top right tile.
	if Rx2_refclk_sel = "R4NT" generate
		Rx2_refclk <= REFCLK_R4NT; 
	elsif Rx2_refclk_sel = "R4NB" generate
		Rx2_refclk <= REFCLK_R4NB; 
	elsif Rx2_refclk_sel = "R4MT" generate
		Rx2_refclk <= REFCLK_R4MT; 
	elsif Rx2_refclk_sel = "R4MB" generate
		Rx2_refclk <= REFCLK_R4MB; 
	elsif Rx2_refclk_sel = "R4LT" generate
		Rx2_refclk <= REFCLK_R4LT; 
	elsif Rx2_refclk_sel = "R4LB" generate
		Rx2_refclk <= REFCLK_R4LB; 
	elsif Rx2_refclk_sel = "R4KT" generate
		Rx2_refclk <= REFCLK_R4KT; 
	elsif Rx2_refclk_sel = "R4KB" generate
		Rx2_refclk <= REFCLK_R4KB; 

-- Bottom right tile.
	elsif Rx2_refclk_sel = "R4FT" generate
		Rx2_refclk <= REFCLK_R4FT; 
	elsif Rx2_refclk_sel = "R4FB" generate
		Rx2_refclk <= REFCLK_R4FB; 
	elsif Rx2_refclk_sel = "R4ET" generate
		Rx2_refclk <= REFCLK_R4ET; 
	elsif Rx2_refclk_sel = "R4EB" generate
		Rx2_refclk <= REFCLK_R4EB; 
	elsif Rx2_refclk_sel = "R4DT" generate
		Rx2_refclk <= REFCLK_R4DT; 
	elsif Rx2_refclk_sel = "R4DB" generate
		Rx2_refclk <= REFCLK_R4DB; 
	elsif Rx2_refclk_sel = "R4CT" generate
		Rx2_refclk <= REFCLK_R4CT; 
	elsif Rx2_refclk_sel = "R4CB" generate
		Rx2_refclk <= REFCLK_R4CB; 
		
-- Top left tile.
	elsif Rx2_refclk_sel = "L1NT" generate
		Rx2_refclk <= REFCLK_L1NT; 
	elsif Rx2_refclk_sel = "L1NB" generate
		Rx2_refclk <= REFCLK_L1NB; 
	elsif Rx2_refclk_sel = "L1MT" generate
		Rx2_refclk <= REFCLK_L1MT; 
	elsif Rx2_refclk_sel = "L1MB" generate
		Rx2_refclk <= REFCLK_L1MB; 
	elsif Rx2_refclk_sel = "L1LT" generate
		Rx2_refclk <= REFCLK_L1LT; 
	elsif Rx2_refclk_sel = "L1LB" generate
		Rx2_refclk <= REFCLK_L1LB; 
	elsif Rx2_refclk_sel = "L1KT" generate
		Rx2_refclk <= REFCLK_L1KT; 
	elsif Rx2_refclk_sel = "L1KB" generate
		Rx2_refclk <= REFCLK_L1KB; 
		
-- Bottom left tile.
	elsif Rx2_refclk_sel = "L1FT" generate
		Rx2_refclk <= REFCLK_L1FT; 
	elsif Rx2_refclk_sel = "L1FB" generate
		Rx2_refclk <= REFCLK_L1FB; 
	elsif Rx2_refclk_sel = "L1ET" generate
		Rx2_refclk <= REFCLK_L1ET; 
	elsif Rx2_refclk_sel = "L1EB" generate
		Rx2_refclk <= REFCLK_L1EB; 
	elsif Rx2_refclk_sel = "L1DT" generate
		Rx2_refclk <= REFCLK_L1DT; 
	elsif Rx2_refclk_sel = "L1DB" generate
		Rx2_refclk <= REFCLK_L1DB; 
	elsif Rx2_refclk_sel = "L1CT" generate
		Rx2_refclk <= REFCLK_L1CT; 
	elsif Rx2_refclk_sel = "L1CB" generate
		Rx2_refclk <= REFCLK_L1CB; 		
		
end generate Gen_Rx2_refclk;	

--##############################################################
--## Rx3_refclk_select  ########################################
--##############################################################

Gen_Rx3_refclk:
-- Top right tile.
	if Rx3_refclk_sel = "R4NT" generate
		Rx3_refclk <= REFCLK_R4NT; 
	elsif Rx3_refclk_sel = "R4NB" generate
		Rx3_refclk <= REFCLK_R4NB; 
	elsif Rx3_refclk_sel = "R4MT" generate
		Rx3_refclk <= REFCLK_R4MT; 
	elsif Rx3_refclk_sel = "R4MB" generate
		Rx3_refclk <= REFCLK_R4MB; 
	elsif Rx3_refclk_sel = "R4LT" generate
		Rx3_refclk <= REFCLK_R4LT; 
	elsif Rx3_refclk_sel = "R4LB" generate
		Rx3_refclk <= REFCLK_R4LB; 
	elsif Rx3_refclk_sel = "R4KT" generate
		Rx3_refclk <= REFCLK_R4KT; 
	elsif Rx3_refclk_sel = "R4KB" generate
		Rx3_refclk <= REFCLK_R4KB; 

-- Bottom right tile.
	elsif Rx3_refclk_sel = "R4FT" generate
		Rx3_refclk <= REFCLK_R4FT; 
	elsif Rx3_refclk_sel = "R4FB" generate
		Rx3_refclk <= REFCLK_R4FB; 
	elsif Rx3_refclk_sel = "R4ET" generate
		Rx3_refclk <= REFCLK_R4ET; 
	elsif Rx3_refclk_sel = "R4EB" generate
		Rx3_refclk <= REFCLK_R4EB; 
	elsif Rx3_refclk_sel = "R4DT" generate
		Rx3_refclk <= REFCLK_R4DT; 
	elsif Rx3_refclk_sel = "R4DB" generate
		Rx3_refclk <= REFCLK_R4DB; 
	elsif Rx3_refclk_sel = "R4CT" generate
		Rx3_refclk <= REFCLK_R4CT; 
	elsif Rx3_refclk_sel = "R4CB" generate
		Rx3_refclk <= REFCLK_R4CB; 
		
-- Top left tile.
	elsif Rx3_refclk_sel = "L1NT" generate
		Rx3_refclk <= REFCLK_L1NT; 
	elsif Rx3_refclk_sel = "L1NB" generate
		Rx3_refclk <= REFCLK_L1NB; 
	elsif Rx3_refclk_sel = "L1MT" generate
		Rx3_refclk <= REFCLK_L1MT; 
	elsif Rx3_refclk_sel = "L1MB" generate
		Rx3_refclk <= REFCLK_L1MB; 
	elsif Rx3_refclk_sel = "L1LT" generate
		Rx3_refclk <= REFCLK_L1LT; 
	elsif Rx3_refclk_sel = "L1LB" generate
		Rx3_refclk <= REFCLK_L1LB; 
	elsif Rx3_refclk_sel = "L1KT" generate
		Rx3_refclk <= REFCLK_L1KT; 
	elsif Rx3_refclk_sel = "L1KB" generate
		Rx3_refclk <= REFCLK_L1KB; 
		
-- Bottom left tile.
	elsif Rx3_refclk_sel = "L1FT" generate
		Rx3_refclk <= REFCLK_L1FT; 
	elsif Rx3_refclk_sel = "L1FB" generate
		Rx3_refclk <= REFCLK_L1FB; 
	elsif Rx3_refclk_sel = "L1ET" generate
		Rx3_refclk <= REFCLK_L1ET; 
	elsif Rx3_refclk_sel = "L1EB" generate
		Rx3_refclk <= REFCLK_L1EB; 
	elsif Rx3_refclk_sel = "L1DT" generate
		Rx3_refclk <= REFCLK_L1DT; 
	elsif Rx3_refclk_sel = "L1DB" generate
		Rx3_refclk <= REFCLK_L1DB; 
	elsif Rx3_refclk_sel = "L1CT" generate
		Rx3_refclk <= REFCLK_L1CT; 
	elsif Rx3_refclk_sel = "L1CB" generate
		Rx3_refclk <= REFCLK_L1CB; 		
		
end generate Gen_Rx3_refclk;

--##############################################################
--## GT0_refclk_select  ########################################
--##############################################################

Gen_GT0_refclk:
-- Top right tile.
	if GT0_refclk_sel = "R4NT" generate
		GT0_refclk <= REFCLK_R4NT; 
	elsif GT0_refclk_sel = "R4NB" generate
		GT0_refclk <= REFCLK_R4NB; 
	elsif GT0_refclk_sel = "R4MT" generate
		GT0_refclk <= REFCLK_R4MT; 
	elsif GT0_refclk_sel = "R4MB" generate
		GT0_refclk <= REFCLK_R4MB; 
	elsif GT0_refclk_sel = "R4LT" generate
		GT0_refclk <= REFCLK_R4LT; 
	elsif GT0_refclk_sel = "R4LB" generate
		GT0_refclk <= REFCLK_R4LB; 
	elsif GT0_refclk_sel = "R4KT" generate
		GT0_refclk <= REFCLK_R4KT; 
	elsif GT0_refclk_sel = "R4KB" generate
		GT0_refclk <= REFCLK_R4KB; 

-- Bottom right tile.
	elsif GT0_refclk_sel = "R4FT" generate
		GT0_refclk <= REFCLK_R4FT; 
	elsif GT0_refclk_sel = "R4FB" generate
		GT0_refclk <= REFCLK_R4FB; 
	elsif GT0_refclk_sel = "R4ET" generate
		GT0_refclk <= REFCLK_R4ET; 
	elsif GT0_refclk_sel = "R4EB" generate
		GT0_refclk <= REFCLK_R4EB; 
	elsif GT0_refclk_sel = "R4DT" generate
		GT0_refclk <= REFCLK_R4DT; 
	elsif GT0_refclk_sel = "R4DB" generate
		GT0_refclk <= REFCLK_R4DB; 
	elsif GT0_refclk_sel = "R4CT" generate
		GT0_refclk <= REFCLK_R4CT; 
	elsif GT0_refclk_sel = "R4CB" generate
		GT0_refclk <= REFCLK_R4CB; 
		
-- Top left tile.
	elsif GT0_refclk_sel = "L1NT" generate
		GT0_refclk <= REFCLK_L1NT; 
	elsif GT0_refclk_sel = "L1NB" generate
		GT0_refclk <= REFCLK_L1NB; 
	elsif GT0_refclk_sel = "L1MT" generate
		GT0_refclk <= REFCLK_L1MT; 
	elsif GT0_refclk_sel = "L1MB" generate
		GT0_refclk <= REFCLK_L1MB; 
	elsif GT0_refclk_sel = "L1LT" generate
		GT0_refclk <= REFCLK_L1LT; 
	elsif GT0_refclk_sel = "L1LB" generate
		GT0_refclk <= REFCLK_L1LB; 
	elsif GT0_refclk_sel = "L1KT" generate
		GT0_refclk <= REFCLK_L1KT; 
	elsif GT0_refclk_sel = "L1KB" generate
		GT0_refclk <= REFCLK_L1KB; 
		
-- Bottom left tile.
	elsif GT0_refclk_sel = "L1FT" generate
		GT0_refclk <= REFCLK_L1FT; 
	elsif GT0_refclk_sel = "L1FB" generate
		GT0_refclk <= REFCLK_L1FB; 
	elsif GT0_refclk_sel = "L1ET" generate
		GT0_refclk <= REFCLK_L1ET; 
	elsif GT0_refclk_sel = "L1EB" generate
		GT0_refclk <= REFCLK_L1EB; 
	elsif GT0_refclk_sel = "L1DT" generate
		GT0_refclk <= REFCLK_L1DT; 
	elsif GT0_refclk_sel = "L1DB" generate
		GT0_refclk <= REFCLK_L1DB; 
	elsif GT0_refclk_sel = "L1CT" generate
		GT0_refclk <= REFCLK_L1CT; 
	elsif GT0_refclk_sel = "L1CB" generate
		GT0_refclk <= REFCLK_L1CB; 		
		
end generate Gen_GT0_refclk;	

--##############################################################
--## GT1_refclk_select  ########################################
--##############################################################

Gen_GT1_refclk:
-- Top right tile.
	if GT1_refclk_sel = "R4NT" generate
		GT1_refclk <= REFCLK_R4NT; 
	elsif GT1_refclk_sel = "R4NB" generate
		GT1_refclk <= REFCLK_R4NB; 
	elsif GT1_refclk_sel = "R4MT" generate
		GT1_refclk <= REFCLK_R4MT; 
	elsif GT1_refclk_sel = "R4MB" generate
		GT1_refclk <= REFCLK_R4MB; 
	elsif GT1_refclk_sel = "R4LT" generate
		GT1_refclk <= REFCLK_R4LT; 
	elsif GT1_refclk_sel = "R4LB" generate
		GT1_refclk <= REFCLK_R4LB; 
	elsif GT1_refclk_sel = "R4KT" generate
		GT1_refclk <= REFCLK_R4KT; 
	elsif GT1_refclk_sel = "R4KB" generate
		GT1_refclk <= REFCLK_R4KB; 

-- Bottom right tile.
	elsif GT1_refclk_sel = "R4FT" generate
		GT1_refclk <= REFCLK_R4FT; 
	elsif GT1_refclk_sel = "R4FB" generate
		GT1_refclk <= REFCLK_R4FB; 
	elsif GT1_refclk_sel = "R4ET" generate
		GT1_refclk <= REFCLK_R4ET; 
	elsif GT1_refclk_sel = "R4EB" generate
		GT1_refclk <= REFCLK_R4EB; 
	elsif GT1_refclk_sel = "R4DT" generate
		GT1_refclk <= REFCLK_R4DT; 
	elsif GT1_refclk_sel = "R4DB" generate
		GT1_refclk <= REFCLK_R4DB; 
	elsif GT1_refclk_sel = "R4CT" generate
		GT1_refclk <= REFCLK_R4CT; 
	elsif GT1_refclk_sel = "R4CB" generate
		GT1_refclk <= REFCLK_R4CB; 
		
-- Top left tile.
	elsif GT1_refclk_sel = "L1NT" generate
		GT1_refclk <= REFCLK_L1NT; 
	elsif GT1_refclk_sel = "L1NB" generate
		GT1_refclk <= REFCLK_L1NB; 
	elsif GT1_refclk_sel = "L1MT" generate
		GT1_refclk <= REFCLK_L1MT; 
	elsif GT1_refclk_sel = "L1MB" generate
		GT1_refclk <= REFCLK_L1MB; 
	elsif GT1_refclk_sel = "L1LT" generate
		GT1_refclk <= REFCLK_L1LT; 
	elsif GT1_refclk_sel = "L1LB" generate
		GT1_refclk <= REFCLK_L1LB; 
	elsif GT1_refclk_sel = "L1KT" generate
		GT1_refclk <= REFCLK_L1KT; 
	elsif GT1_refclk_sel = "L1KB" generate
		GT1_refclk <= REFCLK_L1KB; 
		
-- Bottom left tile.
	elsif GT1_refclk_sel = "L1FT" generate
		GT1_refclk <= REFCLK_L1FT; 
	elsif GT1_refclk_sel = "L1FB" generate
		GT1_refclk <= REFCLK_L1FB; 
	elsif GT1_refclk_sel = "L1ET" generate
		GT1_refclk <= REFCLK_L1ET; 
	elsif GT1_refclk_sel = "L1EB" generate
		GT1_refclk <= REFCLK_L1EB; 
	elsif GT1_refclk_sel = "L1DT" generate
		GT1_refclk <= REFCLK_L1DT; 
	elsif GT1_refclk_sel = "L1DB" generate
		GT1_refclk <= REFCLK_L1DB; 
	elsif GT1_refclk_sel = "L1CT" generate
		GT1_refclk <= REFCLK_L1CT; 
	elsif GT1_refclk_sel = "L1CB" generate
		GT1_refclk <= REFCLK_L1CB; 		
		
end generate Gen_GT1_refclk;	

--##############################################################
--## GT2_refclk_select  ########################################
--##############################################################

Gen_GT2_refclk:
-- Top right tile.
	if GT2_refclk_sel = "R4NT" generate
		GT2_refclk <= REFCLK_R4NT; 
	elsif GT2_refclk_sel = "R4NB" generate
		GT2_refclk <= REFCLK_R4NB; 
	elsif GT2_refclk_sel = "R4MT" generate
		GT2_refclk <= REFCLK_R4MT; 
	elsif GT2_refclk_sel = "R4MB" generate
		GT2_refclk <= REFCLK_R4MB; 
	elsif GT2_refclk_sel = "R4LT" generate
		GT2_refclk <= REFCLK_R4LT; 
	elsif GT2_refclk_sel = "R4LB" generate
		GT2_refclk <= REFCLK_R4LB; 
	elsif GT2_refclk_sel = "R4KT" generate
		GT2_refclk <= REFCLK_R4KT; 
	elsif GT2_refclk_sel = "R4KB" generate
		GT2_refclk <= REFCLK_R4KB; 

-- Bottom right tile.
	elsif GT2_refclk_sel = "R4FT" generate
		GT2_refclk <= REFCLK_R4FT; 
	elsif GT2_refclk_sel = "R4FB" generate
		GT2_refclk <= REFCLK_R4FB; 
	elsif GT2_refclk_sel = "R4ET" generate
		GT2_refclk <= REFCLK_R4ET; 
	elsif GT2_refclk_sel = "R4EB" generate
		GT2_refclk <= REFCLK_R4EB; 
	elsif GT2_refclk_sel = "R4DT" generate
		GT2_refclk <= REFCLK_R4DT; 
	elsif GT2_refclk_sel = "R4DB" generate
		GT2_refclk <= REFCLK_R4DB; 
	elsif GT2_refclk_sel = "R4CT" generate
		GT2_refclk <= REFCLK_R4CT; 
	elsif GT2_refclk_sel = "R4CB" generate
		GT2_refclk <= REFCLK_R4CB; 
		
-- Top left tile.
	elsif GT2_refclk_sel = "L1NT" generate
		GT2_refclk <= REFCLK_L1NT; 
	elsif GT2_refclk_sel = "L1NB" generate
		GT2_refclk <= REFCLK_L1NB; 
	elsif GT2_refclk_sel = "L1MT" generate
		GT2_refclk <= REFCLK_L1MT; 
	elsif GT2_refclk_sel = "L1MB" generate
		GT2_refclk <= REFCLK_L1MB; 
	elsif GT2_refclk_sel = "L1LT" generate
		GT2_refclk <= REFCLK_L1LT; 
	elsif GT2_refclk_sel = "L1LB" generate
		GT2_refclk <= REFCLK_L1LB; 
	elsif GT2_refclk_sel = "L1KT" generate
		GT2_refclk <= REFCLK_L1KT; 
	elsif GT2_refclk_sel = "L1KB" generate
		GT2_refclk <= REFCLK_L1KB; 
		
-- Bottom left tile.
	elsif GT2_refclk_sel = "L1FT" generate
		GT2_refclk <= REFCLK_L1FT; 
	elsif GT2_refclk_sel = "L1FB" generate
		GT2_refclk <= REFCLK_L1FB; 
	elsif GT2_refclk_sel = "L1ET" generate
		GT2_refclk <= REFCLK_L1ET; 
	elsif GT2_refclk_sel = "L1EB" generate
		GT2_refclk <= REFCLK_L1EB; 
	elsif GT2_refclk_sel = "L1DT" generate
		GT2_refclk <= REFCLK_L1DT; 
	elsif GT2_refclk_sel = "L1DB" generate
		GT2_refclk <= REFCLK_L1DB; 
	elsif GT2_refclk_sel = "L1CT" generate
		GT2_refclk <= REFCLK_L1CT; 
	elsif GT2_refclk_sel = "L1CB" generate
		GT2_refclk <= REFCLK_L1CB; 		
		
end generate Gen_GT2_refclk;	

--##############################################################
--## GT3_refclk_select  ########################################
--##############################################################

Gen_GT3_refclk:
-- Top right tile.
	if GT3_refclk_sel = "R4NT" generate
		GT3_refclk <= REFCLK_R4NT; 
	elsif GT3_refclk_sel = "R4NB" generate
		GT3_refclk <= REFCLK_R4NB; 
	elsif GT3_refclk_sel = "R4MT" generate
		GT3_refclk <= REFCLK_R4MT; 
	elsif GT3_refclk_sel = "R4MB" generate
		GT3_refclk <= REFCLK_R4MB; 
	elsif GT3_refclk_sel = "R4LT" generate
		GT3_refclk <= REFCLK_R4LT; 
	elsif GT3_refclk_sel = "R4LB" generate
		GT3_refclk <= REFCLK_R4LB; 
	elsif GT3_refclk_sel = "R4KT" generate
		GT3_refclk <= REFCLK_R4KT; 
	elsif GT3_refclk_sel = "R4KB" generate
		GT3_refclk <= REFCLK_R4KB; 

-- Bottom right tile.
	elsif GT3_refclk_sel = "R4FT" generate
		GT3_refclk <= REFCLK_R4FT; 
	elsif GT3_refclk_sel = "R4FB" generate
		GT3_refclk <= REFCLK_R4FB; 
	elsif GT3_refclk_sel = "R4ET" generate
		GT3_refclk <= REFCLK_R4ET; 
	elsif GT3_refclk_sel = "R4EB" generate
		GT3_refclk <= REFCLK_R4EB; 
	elsif GT3_refclk_sel = "R4DT" generate
		GT3_refclk <= REFCLK_R4DT; 
	elsif GT3_refclk_sel = "R4DB" generate
		GT3_refclk <= REFCLK_R4DB; 
	elsif GT3_refclk_sel = "R4CT" generate
		GT3_refclk <= REFCLK_R4CT; 
	elsif GT3_refclk_sel = "R4CB" generate
		GT3_refclk <= REFCLK_R4CB; 
		
-- Top left tile.
	elsif GT3_refclk_sel = "L1NT" generate
		GT3_refclk <= REFCLK_L1NT; 
	elsif GT3_refclk_sel = "L1NB" generate
		GT3_refclk <= REFCLK_L1NB; 
	elsif GT3_refclk_sel = "L1MT" generate
		GT3_refclk <= REFCLK_L1MT; 
	elsif GT3_refclk_sel = "L1MB" generate
		GT3_refclk <= REFCLK_L1MB; 
	elsif GT3_refclk_sel = "L1LT" generate
		GT3_refclk <= REFCLK_L1LT; 
	elsif GT3_refclk_sel = "L1LB" generate
		GT3_refclk <= REFCLK_L1LB; 
	elsif GT3_refclk_sel = "L1KT" generate
		GT3_refclk <= REFCLK_L1KT; 
	elsif GT3_refclk_sel = "L1KB" generate
		GT3_refclk <= REFCLK_L1KB; 
		
-- Bottom left tile.
	elsif GT3_refclk_sel = "L1FT" generate
		GT3_refclk <= REFCLK_L1FT; 
	elsif GT3_refclk_sel = "L1FB" generate
		GT3_refclk <= REFCLK_L1FB; 
	elsif GT3_refclk_sel = "L1ET" generate
		GT3_refclk <= REFCLK_L1ET; 
	elsif GT3_refclk_sel = "L1EB" generate
		GT3_refclk <= REFCLK_L1EB; 
	elsif GT3_refclk_sel = "L1DT" generate
		GT3_refclk <= REFCLK_L1DT; 
	elsif GT3_refclk_sel = "L1DB" generate
		GT3_refclk <= REFCLK_L1DB; 
	elsif GT3_refclk_sel = "L1CT" generate
		GT3_refclk <= REFCLK_L1CT; 
	elsif GT3_refclk_sel = "L1CB" generate
		GT3_refclk <= REFCLK_L1CB; 		
		
end generate Gen_GT3_refclk;

--##############################################################
--## GT4_refclk_select  ########################################
--##############################################################

Gen_GT4_refclk:
-- Top right tile.
	if GT4_refclk_sel = "R4NT" generate
		GT4_refclk <= REFCLK_R4NT; 
	elsif GT4_refclk_sel = "R4NB" generate
		GT4_refclk <= REFCLK_R4NB; 
	elsif GT4_refclk_sel = "R4MT" generate
		GT4_refclk <= REFCLK_R4MT; 
	elsif GT4_refclk_sel = "R4MB" generate
		GT4_refclk <= REFCLK_R4MB; 
	elsif GT4_refclk_sel = "R4LT" generate
		GT4_refclk <= REFCLK_R4LT; 
	elsif GT4_refclk_sel = "R4LB" generate
		GT4_refclk <= REFCLK_R4LB; 
	elsif GT4_refclk_sel = "R4KT" generate
		GT4_refclk <= REFCLK_R4KT; 
	elsif GT4_refclk_sel = "R4KB" generate
		GT4_refclk <= REFCLK_R4KB; 

-- Bottom right tile.
	elsif GT4_refclk_sel = "R4FT" generate
		GT4_refclk <= REFCLK_R4FT; 
	elsif GT4_refclk_sel = "R4FB" generate
		GT4_refclk <= REFCLK_R4FB; 
	elsif GT4_refclk_sel = "R4ET" generate
		GT4_refclk <= REFCLK_R4ET; 
	elsif GT4_refclk_sel = "R4EB" generate
		GT4_refclk <= REFCLK_R4EB; 
	elsif GT4_refclk_sel = "R4DT" generate
		GT4_refclk <= REFCLK_R4DT; 
	elsif GT4_refclk_sel = "R4DB" generate
		GT4_refclk <= REFCLK_R4DB; 
	elsif GT4_refclk_sel = "R4CT" generate
		GT4_refclk <= REFCLK_R4CT; 
	elsif GT4_refclk_sel = "R4CB" generate
		GT4_refclk <= REFCLK_R4CB; 
		
-- Top left tile.
	elsif GT4_refclk_sel = "L1NT" generate
		GT4_refclk <= REFCLK_L1NT; 
	elsif GT4_refclk_sel = "L1NB" generate
		GT4_refclk <= REFCLK_L1NB; 
	elsif GT4_refclk_sel = "L1MT" generate
		GT4_refclk <= REFCLK_L1MT; 
	elsif GT4_refclk_sel = "L1MB" generate
		GT4_refclk <= REFCLK_L1MB; 
	elsif GT4_refclk_sel = "L1LT" generate
		GT4_refclk <= REFCLK_L1LT; 
	elsif GT4_refclk_sel = "L1LB" generate
		GT4_refclk <= REFCLK_L1LB; 
	elsif GT4_refclk_sel = "L1KT" generate
		GT4_refclk <= REFCLK_L1KT; 
	elsif GT4_refclk_sel = "L1KB" generate
		GT4_refclk <= REFCLK_L1KB; 
		
-- Bottom left tile.
	elsif GT4_refclk_sel = "L1FT" generate
		GT4_refclk <= REFCLK_L1FT; 
	elsif GT4_refclk_sel = "L1FB" generate
		GT4_refclk <= REFCLK_L1FB; 
	elsif GT4_refclk_sel = "L1ET" generate
		GT4_refclk <= REFCLK_L1ET; 
	elsif GT4_refclk_sel = "L1EB" generate
		GT4_refclk <= REFCLK_L1EB; 
	elsif GT4_refclk_sel = "L1DT" generate
		GT4_refclk <= REFCLK_L1DT; 
	elsif GT4_refclk_sel = "L1DB" generate
		GT4_refclk <= REFCLK_L1DB; 
	elsif GT4_refclk_sel = "L1CT" generate
		GT4_refclk <= REFCLK_L1CT; 
	elsif GT4_refclk_sel = "L1CB" generate
		GT4_refclk <= REFCLK_L1CB; 		
		
end generate Gen_GT4_refclk;	

--##############################################################
--## GT5_refclk_select  ########################################
--##############################################################

Gen_GT5_refclk:
-- Top right tile.
	if GT5_refclk_sel = "R4NT" generate
		GT5_refclk <= REFCLK_R4NT; 
	elsif GT5_refclk_sel = "R4NB" generate
		GT5_refclk <= REFCLK_R4NB; 
	elsif GT5_refclk_sel = "R4MT" generate
		GT5_refclk <= REFCLK_R4MT; 
	elsif GT5_refclk_sel = "R4MB" generate
		GT5_refclk <= REFCLK_R4MB; 
	elsif GT5_refclk_sel = "R4LT" generate
		GT5_refclk <= REFCLK_R4LT; 
	elsif GT5_refclk_sel = "R4LB" generate
		GT5_refclk <= REFCLK_R4LB; 
	elsif GT5_refclk_sel = "R4KT" generate
		GT5_refclk <= REFCLK_R4KT; 
	elsif GT5_refclk_sel = "R4KB" generate
		GT5_refclk <= REFCLK_R4KB; 

-- Bottom right tile.
	elsif GT5_refclk_sel = "R4FT" generate
		GT5_refclk <= REFCLK_R4FT; 
	elsif GT5_refclk_sel = "R4FB" generate
		GT5_refclk <= REFCLK_R4FB; 
	elsif GT5_refclk_sel = "R4ET" generate
		GT5_refclk <= REFCLK_R4ET; 
	elsif GT5_refclk_sel = "R4EB" generate
		GT5_refclk <= REFCLK_R4EB; 
	elsif GT5_refclk_sel = "R4DT" generate
		GT5_refclk <= REFCLK_R4DT; 
	elsif GT5_refclk_sel = "R4DB" generate
		GT5_refclk <= REFCLK_R4DB; 
	elsif GT5_refclk_sel = "R4CT" generate
		GT5_refclk <= REFCLK_R4CT; 
	elsif GT5_refclk_sel = "R4CB" generate
		GT5_refclk <= REFCLK_R4CB; 
		
-- Top left tile.
	elsif GT5_refclk_sel = "L1NT" generate
		GT5_refclk <= REFCLK_L1NT; 
	elsif GT5_refclk_sel = "L1NB" generate
		GT5_refclk <= REFCLK_L1NB; 
	elsif GT5_refclk_sel = "L1MT" generate
		GT5_refclk <= REFCLK_L1MT; 
	elsif GT5_refclk_sel = "L1MB" generate
		GT5_refclk <= REFCLK_L1MB; 
	elsif GT5_refclk_sel = "L1LT" generate
		GT5_refclk <= REFCLK_L1LT; 
	elsif GT5_refclk_sel = "L1LB" generate
		GT5_refclk <= REFCLK_L1LB; 
	elsif GT5_refclk_sel = "L1KT" generate
		GT5_refclk <= REFCLK_L1KT; 
	elsif GT5_refclk_sel = "L1KB" generate
		GT5_refclk <= REFCLK_L1KB; 
		
-- Bottom left tile.
	elsif GT5_refclk_sel = "L1FT" generate
		GT5_refclk <= REFCLK_L1FT; 
	elsif GT5_refclk_sel = "L1FB" generate
		GT5_refclk <= REFCLK_L1FB; 
	elsif GT5_refclk_sel = "L1ET" generate
		GT5_refclk <= REFCLK_L1ET; 
	elsif GT5_refclk_sel = "L1EB" generate
		GT5_refclk <= REFCLK_L1EB; 
	elsif GT5_refclk_sel = "L1DT" generate
		GT5_refclk <= REFCLK_L1DT; 
	elsif GT5_refclk_sel = "L1DB" generate
		GT5_refclk <= REFCLK_L1DB; 
	elsif GT5_refclk_sel = "L1CT" generate
		GT5_refclk <= REFCLK_L1CT; 
	elsif GT5_refclk_sel = "L1CB" generate
		GT5_refclk <= REFCLK_L1CB; 		
		
end generate Gen_GT5_refclk;
--##############################################################
--## GT6_refclk_select  ########################################
--##############################################################

Gen_GT6_refclk:
-- Top right tile.
	if GT6_refclk_sel = "R4NT" generate
		GT6_refclk <= REFCLK_R4NT; 
	elsif GT6_refclk_sel = "R4NB" generate
		GT6_refclk <= REFCLK_R4NB; 
	elsif GT6_refclk_sel = "R4MT" generate
		GT6_refclk <= REFCLK_R4MT; 
	elsif GT6_refclk_sel = "R4MB" generate
		GT6_refclk <= REFCLK_R4MB; 
	elsif GT6_refclk_sel = "R4LT" generate
		GT6_refclk <= REFCLK_R4LT; 
	elsif GT6_refclk_sel = "R4LB" generate
		GT6_refclk <= REFCLK_R4LB; 
	elsif GT6_refclk_sel = "R4KT" generate
		GT6_refclk <= REFCLK_R4KT; 
	elsif GT6_refclk_sel = "R4KB" generate
		GT6_refclk <= REFCLK_R4KB; 

-- Bottom right tile.
	elsif GT6_refclk_sel = "R4FT" generate
		GT6_refclk <= REFCLK_R4FT; 
	elsif GT6_refclk_sel = "R4FB" generate
		GT6_refclk <= REFCLK_R4FB; 
	elsif GT6_refclk_sel = "R4ET" generate
		GT6_refclk <= REFCLK_R4ET; 
	elsif GT6_refclk_sel = "R4EB" generate
		GT6_refclk <= REFCLK_R4EB; 
	elsif GT6_refclk_sel = "R4DT" generate
		GT6_refclk <= REFCLK_R4DT; 
	elsif GT6_refclk_sel = "R4DB" generate
		GT6_refclk <= REFCLK_R4DB; 
	elsif GT6_refclk_sel = "R4CT" generate
		GT6_refclk <= REFCLK_R4CT; 
	elsif GT6_refclk_sel = "R4CB" generate
		GT6_refclk <= REFCLK_R4CB; 
		
-- Top left tile.
	elsif GT6_refclk_sel = "L1NT" generate
		GT6_refclk <= REFCLK_L1NT; 
	elsif GT6_refclk_sel = "L1NB" generate
		GT6_refclk <= REFCLK_L1NB; 
	elsif GT6_refclk_sel = "L1MT" generate
		GT6_refclk <= REFCLK_L1MT; 
	elsif GT6_refclk_sel = "L1MB" generate
		GT6_refclk <= REFCLK_L1MB; 
	elsif GT6_refclk_sel = "L1LT" generate
		GT6_refclk <= REFCLK_L1LT; 
	elsif GT6_refclk_sel = "L1LB" generate
		GT6_refclk <= REFCLK_L1LB; 
	elsif GT6_refclk_sel = "L1KT" generate
		GT6_refclk <= REFCLK_L1KT; 
	elsif GT6_refclk_sel = "L1KB" generate
		GT6_refclk <= REFCLK_L1KB; 
		
-- Bottom left tile.
	elsif GT6_refclk_sel = "L1FT" generate
		GT6_refclk <= REFCLK_L1FT; 
	elsif GT6_refclk_sel = "L1FB" generate
		GT6_refclk <= REFCLK_L1FB; 
	elsif GT6_refclk_sel = "L1ET" generate
		GT6_refclk <= REFCLK_L1ET; 
	elsif GT6_refclk_sel = "L1EB" generate
		GT6_refclk <= REFCLK_L1EB; 
	elsif GT6_refclk_sel = "L1DT" generate
		GT6_refclk <= REFCLK_L1DT; 
	elsif GT6_refclk_sel = "L1DB" generate
		GT6_refclk <= REFCLK_L1DB; 
	elsif GT6_refclk_sel = "L1CT" generate
		GT6_refclk <= REFCLK_L1CT; 
	elsif GT6_refclk_sel = "L1CB" generate
		GT6_refclk <= REFCLK_L1CB; 		
		
end generate Gen_GT6_refclk;

--##############################################################
--## GT7_refclk_select  ########################################
--##############################################################

Gen_GT7_refclk:
-- Top right tile.
	if GT7_refclk_sel = "R4NT" generate
		GT7_refclk <= REFCLK_R4NT; 
	elsif GT7_refclk_sel = "R4NB" generate
		GT7_refclk <= REFCLK_R4NB; 
	elsif GT7_refclk_sel = "R4MT" generate
		GT7_refclk <= REFCLK_R4MT; 
	elsif GT7_refclk_sel = "R4MB" generate
		GT7_refclk <= REFCLK_R4MB; 
	elsif GT7_refclk_sel = "R4LT" generate
		GT7_refclk <= REFCLK_R4LT; 
	elsif GT7_refclk_sel = "R4LB" generate
		GT7_refclk <= REFCLK_R4LB; 
	elsif GT7_refclk_sel = "R4KT" generate
		GT7_refclk <= REFCLK_R4KT; 
	elsif GT7_refclk_sel = "R4KB" generate
		GT7_refclk <= REFCLK_R4KB; 

-- Bottom right tile.
	elsif GT7_refclk_sel = "R4FT" generate
		GT7_refclk <= REFCLK_R4FT; 
	elsif GT7_refclk_sel = "R4FB" generate
		GT7_refclk <= REFCLK_R4FB; 
	elsif GT7_refclk_sel = "R4ET" generate
		GT7_refclk <= REFCLK_R4ET; 
	elsif GT7_refclk_sel = "R4EB" generate
		GT7_refclk <= REFCLK_R4EB; 
	elsif GT7_refclk_sel = "R4DT" generate
		GT7_refclk <= REFCLK_R4DT; 
	elsif GT7_refclk_sel = "R4DB" generate
		GT7_refclk <= REFCLK_R4DB; 
	elsif GT7_refclk_sel = "R4CT" generate
		GT7_refclk <= REFCLK_R4CT; 
	elsif GT7_refclk_sel = "R4CB" generate
		GT7_refclk <= REFCLK_R4CB; 
		
-- Top left tile.
	elsif GT7_refclk_sel = "L1NT" generate
		GT7_refclk <= REFCLK_L1NT; 
	elsif GT7_refclk_sel = "L1NB" generate
		GT7_refclk <= REFCLK_L1NB; 
	elsif GT7_refclk_sel = "L1MT" generate
		GT7_refclk <= REFCLK_L1MT; 
	elsif GT7_refclk_sel = "L1MB" generate
		GT7_refclk <= REFCLK_L1MB; 
	elsif GT7_refclk_sel = "L1LT" generate
		GT7_refclk <= REFCLK_L1LT; 
	elsif GT7_refclk_sel = "L1LB" generate
		GT7_refclk <= REFCLK_L1LB; 
	elsif GT7_refclk_sel = "L1KT" generate
		GT7_refclk <= REFCLK_L1KT; 
	elsif GT7_refclk_sel = "L1KB" generate
		GT7_refclk <= REFCLK_L1KB; 
		
-- Bottom left tile.
	elsif GT7_refclk_sel = "L1FT" generate
		GT7_refclk <= REFCLK_L1FT; 
	elsif GT7_refclk_sel = "L1FB" generate
		GT7_refclk <= REFCLK_L1FB; 
	elsif GT7_refclk_sel = "L1ET" generate
		GT7_refclk <= REFCLK_L1ET; 
	elsif GT7_refclk_sel = "L1EB" generate
		GT7_refclk <= REFCLK_L1EB; 
	elsif GT7_refclk_sel = "L1DT" generate
		GT7_refclk <= REFCLK_L1DT; 
	elsif GT7_refclk_sel = "L1DB" generate
		GT7_refclk <= REFCLK_L1DB; 
	elsif GT7_refclk_sel = "L1CT" generate
		GT7_refclk <= REFCLK_L1CT; 
	elsif GT7_refclk_sel = "L1CB" generate
		GT7_refclk <= REFCLK_L1CB; 		
		
end generate Gen_GT7_refclk;

end rtl;